@@ -37,23 +37,21 @@
 #include <string.h>
 #include <time.h>
 #include <lalapps.h>
-#include <processtable.h>
 #include <lal/LALStdio.h>
 #include <lal/LALgetopt.h>
 #include <lal/LALStdlib.h>
 #include <lal/LALConstants.h>
 #include <lal/LIGOMetadataTables.h>
+#include <lal/LIGOMetadataUtils.h>
 #include <lal/LIGOMetadataInspiralUtils.h>
 #include <lal/LIGOMetadataRingdownUtils.h>
-#include <lal/LIGOLwXML.h>
+#include <lal/LIGOLwXMLlegacy.h>
 #include <lal/Units.h>
 #include <lal/Date.h>
-#include <lal/Inject.h>
 #include <lal/InspiralInjectionParams.h>
 #include <lal/GenerateInspiral.h>
 #include <lal/GenerateInspRing.h>
 #include <lal/FindChirp.h>
-#include <lal/GenerateRing.h>
 #include <lal/RingUtils.h>
 #include <lal/LALNoiseModels.h>
 #include <lal/RealFFT.h>
@@ -179,7 +177,7 @@ ProcessParamsTable *next_process_param(
     snprintf( pp->param, LIGOMETA_PARAM_MAX, "-userTag" );
   else
     snprintf( pp->param, LIGOMETA_PARAM_MAX, "--%s", name );
-  strncpy( pp->type, type, LIGOMETA_TYPE_MAX );
+  strncpy( pp->type, type, LIGOMETA_TYPE_MAX - 1 );
   va_start( ap, fmt );
   vsnprintf( pp->value, LIGOMETA_VALUE_MAX, fmt, ap );
   va_end( ap );
