@@ -24,11 +24,10 @@
 #include <string.h>
 
 #include <lalapps.h>
-#include <processtable.h>
 #include <lal/LALStdio.h>
 #include <lal/LALgetopt.h>
 #include <lal/LALStdlib.h>
-#include <lal/LIGOLwXML.h>
+#include <lal/LIGOLwXMLlegacy.h>
 #include <lal/LIGOLwXMLInspiralRead.h>
 #include <lal/Date.h>
 #include <lal/FindChirp.h>
@@ -110,7 +109,6 @@ int main(int argc, char *argv[])
   LALStatus        status=blank_status;
   CHAR                inputfile[FILENAME_MAX];
   CHAR                outputpath[1000];
-  CHAR            adjustedfile[FILENAME_MAX+10];
   CHAR                injtype[30];
   CHAR                det_name[10];
   INT8                detectorFlags;
@@ -119,6 +117,7 @@ int main(int argc, char *argv[])
   REAL8                injLength=100.0; /* Ten seconds at end */
   REAL8                LeadupTime=95.0;
   REAL8                dynRange=1.0/3.0e-23;
+  int                  result;
 
   UINT4                Nsamples,det_idx,i,inj_num=0;
   ActuationParametersType actuationParams[LAL_NUM_IFO];
@@ -379,7 +378,12 @@ int main(int argc, char *argv[])
       else sprintf(massBin,"BBH");
       
       if (!(skipASCIIoutput)){
-        sprintf(outfilename,"%s%s%i_CBC_%s_%i_%s_%s.txt",outputpath,"/",inj_epoch.gpsSeconds,massBin,inj_num,injtype,det_name);
+        result = snprintf(outfilename,sizeof(outfilename),"%s%s%i_CBC_%s_%i_%s_%s.txt",outputpath,"/",inj_epoch.gpsSeconds,massBin,inj_num,injtype,det_name);
+        if (result < 0 || (size_t)result > sizeof(outfilename) - 1)
+        {
+          fprintf(stderr, "ERROR: file name too long: '%s'\n", outfilename);
+          exit(1);
+        }
         outfile=fopen(outfilename,"w");
         fprintf(stdout,"Injected signal %i for %s into file %s\n",inj_num,det_name,outfilename);
         for(i=0;i<actuationTimeSeries->data->length;i++) fprintf(outfile,"%10.10e\n",actuationTimeSeries->data->data[i]);
@@ -433,7 +437,12 @@ int main(int argc, char *argv[])
         /* add time series as a channel to the frame */
         XLALFrameAddREAL4TimeSeriesSimData( frame, TimeSeries );
         /* write frame */
-        sprintf(fname,"%s%s%s-INSP%i_HWINJ_STRAIN-%i-%i.gwf",outputpath,"/",det_name, inj_num, inj_epoch.gpsSeconds, (UINT4)injLength);
+        result = snprintf(fname,sizeof(fname),"%s%s%s-INSP%i_HWINJ_STRAIN-%i-%i.gwf",outputpath,"/",det_name, inj_num, inj_epoch.gpsSeconds, (UINT4)injLength);
+        if (result < 0 || (size_t)result > sizeof(fname) - 1)
+        {
+          fprintf( stderr, "ERROR: file name too long: '%s'\n", fname );
+          exit( 1 );
+        }
         /*sprintf(fname, "%s%s%s",outputpath, "/", fname);*/
         if (XLALFrameWrite( frame, fname) != 0)
         {
@@ -526,8 +535,8 @@ int main(int argc, char *argv[])
     MDT.simInspiralTable = headTable;
         
     fprintf(stderr,"Overwriting %s with adjusted distances\n",inputfile);
-    strncat(adjustedfile,inputfile,strlen(inputfile)-4); /* Cut off the .xml */
-    sprintf(inputfile,"%s_adj.xml",adjustedfile);
+    inputfile[strlen(inputfile)-4] = 0; /* Cut off the .xml */
+    strncat(inputfile,"_adj.xml",FILENAME_MAX-1);
     xmlfp=XLALOpenLIGOLwXMLFile((const char *)inputfile);
     if(xmlfp==NULL) fprintf(stderr,"Error! Cannot open %s for writing\n",inputfile);
     LAL_CALL( LALBeginLIGOLwXMLTable( &status, xmlfp, sim_inspiral_table ), &status );
