@@ -14,12 +14,15 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
+from __future__ import print_function
 
 ##############################################################################
 # import standard modules and append the lalapps prefix to the python path
-import sys, os, shutil
-from itertools import cycle, izip
-import subprocess, socket, tempfile
+import os
+import socket
+import subprocess
+import sys
+import tempfile
 
 ##############################################################################
 # import the modules we need to build the pipeline
@@ -33,7 +36,7 @@ def which(prog):
     which = subprocess.Popen(['/usr/bin/which', prog], stdout=subprocess.PIPE)
     out = which.stdout.read().strip()
     if not out:
-        print >>sys.stderr, "ERROR: could not find %s in your path, have you built the proper software and source the proper env. scripts?" % (prog,prog)
+        print("ERROR: could not find %s in your path, have you built the proper software and source the proper env. scripts?" % (prog,prog), file=sys.stderr)
         raise ValueError
     return out
 
@@ -91,7 +94,7 @@ class SBankJob(inspiral.InspiralAnalysisJob):
         if cp.has_section("accounting"):
             self.add_condor_cmd('accounting_group', cp.get("accounting", "accounting-group"))
             if cp.has_option("accounting", "accounting-group-user"):
-		self.add_condor_cmd('accounting_group_user', cp.get("accounting", "accounting-group-user"))
+                self.add_condor_cmd('accounting_group_user', cp.get("accounting", "accounting-group-user"))
         self.add_condor_cmd('getenv','True')
         self.add_condor_cmd('request_memory', '3999')
         if "OMP_NUM_THREADS" in os.environ:
@@ -133,7 +136,7 @@ class SBankChooseMchirpBoundariesJob(inspiral.InspiralAnalysisJob):
         if cp.has_section("accounting"):
             self.add_condor_cmd('accounting_group', cp.get("accounting", "accounting-group"))
             if cp.has_option("accounting", "accounting-group-user"):
-		self.add_condor_cmd('accounting_group_user', cp.get("accounting", "accounting-group-user"))
+                self.add_condor_cmd('accounting_group_user', cp.get("accounting", "accounting-group-user"))
         self.add_condor_cmd('getenv','True')
 
 
@@ -171,7 +174,7 @@ class LWAddJob(pipeline.CondorDAGJob):
         if cp.has_section("accounting"):
             self.add_condor_cmd('accounting_group', cp.get("accounting", "accounting-group"))
             if cp.has_option("accounting", "accounting-group-user"):
-		self.add_condor_cmd('accounting_group_user', cp.get("accounting", "accounting-group-user"))
+                self.add_condor_cmd('accounting_group_user', cp.get("accounting", "accounting-group-user"))
         self.tag_base = tag_base
         self.add_condor_cmd('environment',"KMP_LIBRARY=serial;MKL_SERIAL=yes")
         self.set_sub_file(tag_base+'.sub')
