@@ -45,9 +45,8 @@
 #include <lal/AVFactories.h>
 #include <lal/NRWaveIO.h>
 #include <lal/NRWaveInject.h>
-#include <lal/LIGOLwXML.h>
+#include <lal/LIGOLwXMLlegacy.h>
 #include <lal/LIGOLwXMLRead.h>
-#include <lal/Inject.h>
 #include <lal/FileIO.h>
 #include <lal/Units.h>
 #include <lal/FrequencySeries.h>
@@ -64,7 +63,6 @@
 
 #include <LALAppsVCSInfo.h>
 
-#include <processtable.h>
 #include "inspiral.h"
 
 /* program info */
