@@ -39,7 +39,6 @@
 
 #include <lalapps.h>
 #include <series.h>
-#include <processtable.h>
 
 #include <lal/LALConfig.h>
 #include <lal/LALgetopt.h>
@@ -49,7 +48,8 @@
 #include <lal/LALDatatypes.h>
 #include <lal/AVFactories.h>
 #include <lal/LIGOMetadataTables.h>
-#include <lal/LIGOLwXML.h>
+#include <lal/LIGOMetadataUtils.h>
+#include <lal/LIGOLwXMLlegacy.h>
 #include <lal/LIGOLwXMLRead.h>
 #include <lal/Units.h>
 #include <lal/Date.h>
