@@ -179,13 +179,13 @@ int plan_problem(char type,            /**< 'r' for real or 'c' for complex tran
     case 3:
       planning_flags |= FFTW_EXHAUSTIVE;
       /* Fall through: */
-#if __GNUC__ >= 7
+#if __GNUC__ >= 7 && !defined __INTEL_COMPILER
       __attribute__ ((fallthrough));
 #endif
     case 2:
       planning_flags |= FFTW_PATIENT;
       /* Fall through */
-#if __GNUC__ >= 7
+#if __GNUC__ >= 7 && !defined __INTEL_COMPILER
       __attribute__ ((fallthrough));
 #endif
     case 1:
