@@ -28,17 +28,18 @@ Excess power pipeline construction tools.
 """
 
 
+from __future__ import print_function
+
+
 import errno
-import math
 import os
-import random
 import sys
 import time
 
 
+from ligo import segments
+from ligo.segments import utils as segmentsUtils
 from glue import iterutils
-from glue import segments
-from glue import segmentsUtils
 from glue import pipeline
 import lal
 from lal.utils import CacheEntry
@@ -87,7 +88,7 @@ def get_triggers_dir(config_parser):
 def make_dir_if_not_exists(dir):
 	try:
 		os.mkdir(dir)
-	except OSError, e:
+	except OSError as e:
 		if e.errno != errno.EEXIST:
 			# OK if directory exists, otherwise report error
 			raise e
@@ -171,7 +172,7 @@ def make_cache_entry(input_cache, description, path):
 
 def collect_output_caches(parents):
 	cache = [(cache_entry, parent) for parent in parents for cache_entry in parent.get_output_cache()]
-	cache.sort(key = lambda (cache_entry, parent): cache_entry.segment)
+	cache.sort(key = lambda x: x[0].segment)
 	return cache
 
 
@@ -197,7 +198,7 @@ def match_nodes_to_caches(nodes, caches):
 			node_group.add(index[cache_entry])
 
 	# how many nodes didn't get used?
-	unused = len(nodes) - len(reduce(lambda a, b: a | b, node_groups))
+	unused = len(nodes) - len(set.union(*node_groups))
 
 	# done
 	return node_groups, unused
@@ -217,7 +218,7 @@ def cache_span(cache):
 def write_output_cache(nodes, filename):
 	f = file(filename, "w")
 	for cache_entry, node in collect_output_caches(nodes):
-		print >>f, str(cache_entry)
+		print(str(cache_entry), file=f)
 
 
 #
@@ -308,7 +309,7 @@ class BurstInjNode(pipeline.CondorDAGNode,pipeline.AnalysisNode):
 
 	def get_user_tag(self):
 		if self.output_cache:
-			raise AttributeError, "cannot change attributes after computing output cache"
+			raise AttributeError("cannot change attributes after computing output cache")
 		return self.__usertag
 
 	def set_time_slide_file(self, filename):
@@ -319,7 +320,7 @@ class BurstInjNode(pipeline.CondorDAGNode,pipeline.AnalysisNode):
 
 	def set_start(self, start):
 		if self.output_cache:
-			raise AttributeError, "cannot change attributes after computing output cache"
+			raise AttributeError("cannot change attributes after computing output cache")
 		self.add_var_opt("gps-start-time", start)
 
 	def get_start(self):
@@ -327,7 +328,7 @@ class BurstInjNode(pipeline.CondorDAGNode,pipeline.AnalysisNode):
 
 	def set_end(self, end):
 		if self.output_cache:
-			raise AttributeError, "cannot change attributes after computing output cache"
+			raise AttributeError("cannot change attributes after computing output cache")
 		self.add_var_opt("gps-end-time", end)
 
 	def get_end(self):
@@ -350,7 +351,7 @@ class BurstInjNode(pipeline.CondorDAGNode,pipeline.AnalysisNode):
 	def get_output(self):
 		if self._AnalysisNode__output is None:
 			if None in (self.get_start(), self.get_end(), self.__usertag):
-				raise ValueError, "start time, end time, ifo, or user tag has not been set"
+				raise ValueError("start time, end time, ifo, or user tag has not been set")
 			seg = segments.segment(lal.LIGOTimeGPS(self.get_start()), lal.LIGOTimeGPS(self.get_end()))
 			self.set_output(os.path.join(self.output_dir, "G1+H1+H2+L1+T1+V1-INJECTIONS_%s-%d-%d.xml.gz" % (self.__usertag, int(self.get_start()), int(self.get_end() - self.get_start()))))
 		return self._AnalysisNode__output
@@ -396,14 +397,14 @@ class PowerNode(pipeline.AnalysisNode):
 		the config file.
 		"""
 		if self.output_cache:
-			raise AttributeError, "cannot change attributes after computing output cache"
+			raise AttributeError("cannot change attributes after computing output cache")
 		pipeline.AnalysisNode.set_ifo(self, instrument)
 		for optvalue in self.job()._AnalysisJob__cp.items("lalapps_power_%s" % instrument):
 			self.add_var_arg("--%s %s" % optvalue)
 
 	def set_user_tag(self, tag):
 		if self.output_cache:
-			raise AttributeError, "cannot change attributes after computing output cache"
+			raise AttributeError("cannot change attributes after computing output cache")
 		self.__usertag = tag
 		self.add_var_opt("user-tag", self.__usertag)
 
@@ -426,7 +427,7 @@ class PowerNode(pipeline.AnalysisNode):
 	def get_output(self):
 		if self._AnalysisNode__output is None:
 			if None in (self.get_start(), self.get_end(), self.get_ifo(), self.__usertag):
-				raise ValueError, "start time, end time, ifo, or user tag has not been set"
+				raise ValueError("start time, end time, ifo, or user tag has not been set")
 			seg = segments.segment(lal.LIGOTimeGPS(self.get_start()), lal.LIGOTimeGPS(self.get_end()))
 			self.set_output(os.path.join(self.output_dir, "%s-POWER_%s-%d-%d.xml.gz" % (self.get_ifo(), self.__usertag, int(self.get_start()), int(self.get_end()) - int(self.get_start()))))
 		return self._AnalysisNode__output
@@ -497,7 +498,7 @@ class LigolwAddNode(pipeline.LigolwAddNode):
 	def write_input_files(self, *args):
 		f = file(self.cache_name, "w")
 		for c in self.input_cache:
-			print >>f, str(c)
+			print(str(c), file=f)
 		pipeline.LigolwAddNode.write_input_files(self, *args)
 
 	def get_output_files(self):
@@ -520,7 +521,7 @@ class BucutJob(pipeline.CondorDAGJob):
 
 		self.files_per_bucut = get_files_per_bucut(config_parser)
 		if self.files_per_bucut < 1:
-			raise ValueError, "files_per_bucut < 1"
+			raise ValueError("files_per_bucut < 1")
 
 
 class BucutNode(pipeline.CondorDAGNode):
@@ -568,7 +569,7 @@ class BuclusterJob(pipeline.CondorDAGJob):
 
 		self.files_per_bucluster = get_files_per_bucluster(config_parser)
 		if self.files_per_bucluster < 1:
-			raise ValueError, "files_per_bucluster < 1"
+			raise ValueError("files_per_bucluster < 1")
 
 
 class BuclusterNode(pipeline.CondorDAGNode):
@@ -593,7 +594,7 @@ class BuclusterNode(pipeline.CondorDAGNode):
 	def write_input_files(self, *args):
 		f = file(self.cache_name, "w")
 		for c in self.input_cache:
-			print >>f, str(c)
+			print(str(c), file=f)
 		pipeline.CondorDAGNode.write_input_files(self, *args)
 
 	def get_input_cache(self):
@@ -621,7 +622,7 @@ class BinjfindJob(pipeline.CondorDAGJob):
 
 		self.files_per_binjfind = get_files_per_binjfind(config_parser)
 		if self.files_per_binjfind < 1:
-			raise ValueError, "files_per_binjfind < 1"
+			raise ValueError("files_per_binjfind < 1")
 
 
 class BinjfindNode(pipeline.CondorDAGNode):
@@ -667,7 +668,7 @@ class BurcaJob(pipeline.CondorDAGJob):
 
 		self.files_per_burca = get_files_per_burca(config_parser)
 		if self.files_per_burca < 1:
-			raise ValueError, "files_per_burca < 1"
+			raise ValueError("files_per_burca < 1")
 
 
 class Burca2Job(pipeline.CondorDAGJob):
@@ -746,7 +747,7 @@ class SQLiteNode(pipeline.CondorDAGNode):
 
 	def add_input_cache(self, cache):
 		if self.output_cache:
-			raise AttributeError, "cannot change attributes after computing output cache"
+			raise AttributeError("cannot change attributes after computing output cache")
 		self.input_cache.extend(cache)
 		for c in cache:
 			filename = c.path
@@ -758,7 +759,7 @@ class SQLiteNode(pipeline.CondorDAGNode):
 
 	def set_output(self, filename):
 		if self.output_cache:
-			raise AttributeError, "cannot change attributes after computing output cache"
+			raise AttributeError("cannot change attributes after computing output cache")
 		self.add_macro("macrodatabase", filename)
 
 	def get_input_cache(self):
@@ -805,7 +806,7 @@ class BurcaTailorNode(pipeline.CondorDAGNode):
 
 	def add_input_cache(self, cache):
 		if self.output_cache:
-			raise AttributeError, "cannot change attributes after computing output cache"
+			raise AttributeError("cannot change attributes after computing output cache")
 		self.input_cache.extend(cache)
 		for c in cache:
 			filename = c.path
@@ -817,7 +818,7 @@ class BurcaTailorNode(pipeline.CondorDAGNode):
 
 	def set_output(self, description):
 		if self.output_cache:
-			raise AttributeError, "cannot change attributes after computing output cache"
+			raise AttributeError("cannot change attributes after computing output cache")
 		cache_entry = make_cache_entry(self.input_cache, description, "")
 		filename = os.path.join(self.output_dir, "%s-%s-%d-%d.xml.gz" % (cache_entry.observatory, cache_entry.description, int(cache_entry.segment[0]), int(abs(cache_entry.segment))))
 		self.add_var_opt("output", filename)
@@ -831,7 +832,7 @@ class BurcaTailorNode(pipeline.CondorDAGNode):
 
 	def get_output_cache(self):
 		if not self.output_cache:
-			raise AttributeError, "must call set_output(description) first"
+			raise AttributeError("must call set_output(description) first")
 		return self.output_cache
 
 	def write_input_files(self, *args):
@@ -840,7 +841,7 @@ class BurcaTailorNode(pipeline.CondorDAGNode):
 			if "--add-from-cache" in arg:
 				f = file(self.cache_name, "w")
 				for c in self.input_cache:
-					print >>f, str(c)
+					print(str(c), file=f)
 				pipeline.CondorDAGNode.write_input_files(self, *args)
 				break
 
@@ -949,7 +950,7 @@ def psds_from_job_length(timing_params, t):
 	seconds.  In general, the return value is a non-integer.
 	"""
 	if t < 0:
-		raise ValueError, t
+		raise ValueError(t)
 	# convert to samples, and remove filter corruption
 	t = t * timing_params.resample_rate - 2 * timing_params.filter_corruption
 	if t < timing_params.psd_length:
@@ -963,7 +964,7 @@ def job_length_from_psds(timing_params, psds):
 	of the job in seconds.
 	"""
 	if psds < 1:
-		raise ValueError, psds
+		raise ValueError(psds)
 	# number of samples
 	result = (psds - 1) * timing_params.psd_shift + timing_params.psd_length
 	# add filter corruption
@@ -1254,7 +1255,7 @@ def make_burca2_fragment(dag, coinc_cache, likelihood_parents, tag):
 	likelihood_data_cache_filename = os.path.join(burca2job.cache_dir, "burca2_%s.cache" % tag)
 	likelihood_data_cache_file = file(likelihood_data_cache_filename, "w")
 	for cache_entry in [cache_entry for node in likelihood_parents for cache_entry in node.get_output_cache()]:
-		print >>likelihood_data_cache_file, str(cache_entry)
+		print(str(cache_entry), file=likelihood_data_cache_file)
 
 	nodes = set()
 	max_cost_per_job = 10	# 10000 s -equivalent files
@@ -1288,7 +1289,7 @@ def make_burca2_fragment(dag, coinc_cache, likelihood_parents, tag):
 
 def make_datafind_stage(dag, seglists, verbose = False):
 	if verbose:
-		print >>sys.stderr, "building ligo_data_find jobs ..."
+		print("building ligo_data_find jobs ...", file=sys.stderr)
 
 	#
 	# Fill gaps smaller than the padding added to each datafind job.
@@ -1310,7 +1311,7 @@ def make_datafind_stage(dag, seglists, verbose = False):
 	nodes = set()
 	for seg, instrument in segs:
 		if verbose:
-			print >>sys.stderr, "making datafind job for %s spanning %s" % (instrument, seg)
+			print("making datafind job for %s spanning %s" % (instrument, seg), file=sys.stderr)
 		new_nodes = make_datafind_fragment(dag, instrument, seg)
 		nodes |= new_nodes
 
@@ -1352,7 +1353,7 @@ def make_power_segment_fragment(dag, datafindnodes, instrument, segment, tag, ti
 		injargs = {}
 	seglist = split_segment(timing_params, segment, psds_per_job)
 	if verbose:
-		print >>sys.stderr, "Segment split: " + str(seglist)
+		print("Segment split: " + str(seglist), file=sys.stderr)
 	nodes = set()
 	for seg in seglist:
 		nodes |= make_power_fragment(dag, datafindnodes | binjnodes, instrument, seg, tag, framecache, injargs = injargs)
@@ -1369,12 +1370,12 @@ def make_single_instrument_stage(dag, datafinds, seglistdict, tag, timing_params
 	for instrument, seglist in seglistdict.iteritems():
 		for seg in seglist:
 			if verbose:
-				print >>sys.stderr, "generating %s fragment %s" % (instrument, str(seg))
+				print("generating %s fragment %s" % (instrument, str(seg)), file=sys.stderr)
 
 			# find the datafind job this job is going to need
 			dfnodes = set([node for node in datafinds if (node.get_ifo() == instrument) and (seg in segments.segment(node.get_start(), node.get_end()))])
 			if len(dfnodes) != 1:
-				raise ValueError, "error, not exactly 1 datafind is suitable for trigger generator job at %s in %s" % (str(seg), instrument)
+				raise ValueError("error, not exactly 1 datafind is suitable for trigger generator job at %s in %s" % (str(seg), instrument))
 
 			# trigger generator jobs
 			nodes += make_power_segment_fragment(dag, dfnodes, instrument, seg, tag, timing_params, psds_per_job, binjnodes = binjnodes, verbose = verbose)
@@ -1398,7 +1399,7 @@ def group_coinc_parents(parents, offset_vectors, extentlimit = None, verbose = F
 		return []
 
 	if verbose:
-		print >>sys.stderr, "Grouping jobs for coincidence analysis:"
+		print("Grouping jobs for coincidence analysis:", file=sys.stderr)
 
 	#
 	# use ligolw_cafe to group each output file according to how they
@@ -1444,13 +1445,13 @@ def group_coinc_parents(parents, offset_vectors, extentlimit = None, verbose = F
 	#
 
 	if verbose:
-		print >>sys.stderr, "Matching jobs to caches ..."
+		print("Matching jobs to caches ...", file=sys.stderr)
 	parent_groups, unused = match_nodes_to_caches(parents, caches)
 	if verbose and unused:
 		# there were parents that didn't match any caches.  this
 		# happens if ligolw_cafe decides their outputs aren't
 		# needed
-		print >>sys.stderr, "Notice:  %d jobs (of %d) produce output that will not be used by a coincidence job" % (unused, len(parents))
+		print("Notice:  %d jobs (of %d) produce output that will not be used by a coincidence job" % (unused, len(parents)), file=sys.stderr)
 
 	#
 	# done
