@@ -201,13 +201,13 @@ int main(int argc, char **argv){
       fprintf(stderr, "Performing test against the existing ephemeris.\n");
 
     /* get the path to LALPULSAR from the environment variables */
-    if((lalpath = getenv("LALPULSAR_PREFIX")) == NULL){
-      fprintf(stderr, "LALPULSAR_PREFIX environment variable not set. Cannot perform test!\n");
+    if((lalpath = getenv("LALPULSAR_DATADIR")) == NULL){
+      fprintf(stderr, "LALPULSAR_DATADIR environment variable not set. Cannot perform test!\n");
       return TESTFAIL;
     }
 
     /* set the name of one of the earth ephemeris files in LAL */
-    sprintf(earthEphem, "%s/share/lalpulsar/earth98.dat", lalpath);
+    sprintf(earthEphem, "%s/earth98.dat", lalpath);
 
     /* get JPL ephemeris files - only try if TEMPO2 is installed and the TEMPO2
        environment variable is set */
@@ -925,7 +925,7 @@ void get_input_args(inputParams_t *inputParams, INT4 argc, CHAR *argv[]){
         else
           fprintf(stderr, "Error passing option %s with argument %s\n",
             long_options[option_index].name, LALoptarg);
-#if __GNUC__ >= 7
+#if __GNUC__ >= 7 && !defined __INTEL_COMPILER
         __attribute__ ((fallthrough));
 #endif
       case 'h': /* help message */
