@@ -27,16 +27,15 @@
 #include <stdio.h>
 
 #if defined(HAVE_LIBCFITSIO)
+// disable -Wstrict-prototypes flag for this header file as this causes
+// a build failure for cfitsio-3.440+
+#pragma GCC diagnostic ignored "-Wstrict-prototypes"
 #include <fitsio.h>
+#pragma GCC diagnostic pop
 #else
 #error CFITSIO library is not available
 #endif
 
-#if !defined(PAGER) || !defined(HAVE_POPEN) || !defined(HAVE_PCLOSE)
-#define popen(...) stdout
-#define pclose(...)
-#endif
-
 int main(int argc, char *argv[])
 {
   fitsfile *fptr;         /* FITS file pointer, defined in fitsio.h */
@@ -64,11 +63,15 @@ int main(int argc, char *argv[])
     return (0);
   }
 
+#if defined(PAGER) && defined(HAVE_POPEN) && defined(HAVE_PCLOSE)
   FILE *fout = popen(PAGER, "w");
   if (fout == NULL) {
     fprintf(stderr, "Could not execute '%s'\n", PAGER);
     return (1);
   }
+#else
+  FILE *fout = stdout;
+#endif
 
   if (!fits_open_file(&fptr, argv[1], READONLY, &status)) {
     fits_get_hdu_num(fptr, &hdupos);  /* Get the current HDU position */
@@ -106,7 +109,9 @@ int main(int argc, char *argv[])
     fits_close_file(fptr, &status);
   }
 
+#if defined(PAGER) && defined(HAVE_POPEN) && defined(HAVE_PCLOSE)
   pclose(fout);
+#endif
 
   if (status) {
     fits_report_error(stderr, status);  /* print any error message */
