@@ -125,7 +125,6 @@ typedef struct {
 
 ///////////EXTRA FXN DEFS//////////////
 
-static BOOLEAN is_valid_detector(const char *channel);
 static int compareSFTloc(const void *ptr1, const void *ptr2);
 static UINT4 read_sft_bins_from_fp(SFTtype *ret, UINT4 *firstBinRead, UINT4 firstBin2read, UINT4 lastBin2read, FILE *fp);
 static int read_sft_header_from_fp(FILE *fp, SFTtype  *header, UINT4 *version, UINT8 *crc64, BOOLEAN *swapEndian, CHAR **SFTcomment, UINT4 *numBins);
@@ -165,7 +164,7 @@ int main(int argc, char **argv)
 	REAL8 PSD, AMPPSD, PSDWT, AMPPSDWT, weight, thispower, thisavepower, scalefactor;
 	REAL8 PWA_TAVGWT, PWA_SUMWT;
 	REAL8 f = 0, f0 = 0, deltaF = 0;
-	CHAR outbase[256], outfile[256], outfile2[256], outfile3[256], outfile4[256] , outfile5[256];
+	CHAR outbase[256], outfile[512], outfile2[512], outfile3[512], outfile4[512] , outfile5[512];
 	//    REAL8 NumBinsAvg =0;
 	REAL8 timebaseline = 0;
 
@@ -201,8 +200,8 @@ int main(int argc, char **argv)
 
     XLAL_CHECK_MAIN( XLALRegisterNamedUvar(&SFTpatt,      "SFTs",         STRING, 'p', REQUIRED, "SFT location/pattern" ) == XLAL_SUCCESS, XLAL_EFUNC);
     XLAL_CHECK_MAIN( XLALRegisterNamedUvar(&IFO,          "IFO",          STRING, 'I', REQUIRED, "Detector" ) == XLAL_SUCCESS, XLAL_EFUNC);
-    XLAL_CHECK_MAIN( XLALRegisterNamedUvar(&startGPS,     "startGPS",     INT4,   's', REQUIRED, "Starting GPS time" ) == XLAL_SUCCESS, XLAL_EFUNC);
-    XLAL_CHECK_MAIN( XLALRegisterNamedUvar(&endGPS,       "endGPS",       INT4,   'e', REQUIRED, "Ending GPS time" ) == XLAL_SUCCESS, XLAL_EFUNC);
+    XLAL_CHECK_MAIN( XLALRegisterNamedUvar(&startGPS,     "startGPS",     INT4,   's', REQUIRED, "Starting GPS time (SFT timestamps must be >= this)" ) == XLAL_SUCCESS, XLAL_EFUNC);
+    XLAL_CHECK_MAIN( XLALRegisterNamedUvar(&endGPS,       "endGPS",       INT4,   'e', REQUIRED, "Ending GPS time (SFT timestamps must be < this)" ) == XLAL_SUCCESS, XLAL_EFUNC);
     XLAL_CHECK_MAIN( XLALRegisterNamedUvar(&f_min,        "fMin",         REAL8,  'f', REQUIRED, "Minimum frequency" ) == XLAL_SUCCESS, XLAL_EFUNC);
     XLAL_CHECK_MAIN( XLALRegisterNamedUvar(&f_max,        "fMax",         REAL8,  'F', REQUIRED, "Maximum frequency" ) == XLAL_SUCCESS, XLAL_EFUNC);
     XLAL_CHECK_MAIN( XLALRegisterNamedUvar(&blocksRngMed, "blocksRngMed", INT4,   'w', OPTIONAL, "Running Median window size") == XLAL_SUCCESS, XLAL_EFUNC);
@@ -258,13 +257,13 @@ int main(int argc, char **argv)
 	if (XLALUserVarWasSet(&outputBname))
 		strcpy(outbase, outputBname);
 	else
-		sprintf(outbase, "spec_%.2f_%.2f_%s_%d_%d", f_min, f_max, constraints.detector, startTime.gpsSeconds, endTime.gpsSeconds);/*cg; this is the default name for producing the output files, the different suffixes are just added to this*/
-	sprintf(outfile, "%s", outbase);/*cg; name of first file to be output*/
-	sprintf(outfile2, "%s_timestamps", outbase);/*cg: name of second file to be output*/
-	sprintf(outfile3, "%s.txt", outbase);/*cg; name of third file to be output*/
-	sprintf(outfile4, "%s_date", outbase);/*cg;file for outputting the date, which is used in matlab plotting.*/
+	snprintf(outbase, sizeof(outbase), "spec_%.2f_%.2f_%s_%d_%d", f_min, f_max, constraints.detector, startTime.gpsSeconds, endTime.gpsSeconds);/*cg; this is the default name for producing the output files, the different suffixes are just added to this*/
+	snprintf(outfile, sizeof(outfile), "%s", outbase);/*cg; name of first file to be output*/
+	snprintf(outfile2, sizeof(outfile2), "%s_timestamps", outbase);/*cg: name of second file to be output*/
+	snprintf(outfile3, sizeof(outfile3), "%s.txt", outbase);/*cg; name of third file to be output*/
+	snprintf(outfile4, sizeof(outfile4), "%s_date", outbase);/*cg;file for outputting the date, which is used in matlab plotting.*/
 	// ADDED FOR SPEC_AVG_LONG for use in cumulative plotting
-	sprintf(outfile5, "%s_PWA.txt", outbase);
+	snprintf(outfile5, sizeof(outfile5), "%s_PWA.txt", outbase);
 
 	fp = fopen(outfile, "w");/*cg;  open all three files for writing, if they don't exist create them, if they do exist overwrite them*/
 	fp2 = fopen(outfile2, "w");
@@ -1334,7 +1333,7 @@ read_v2_header_from_fp(FILE *fp, SFTtype *header, UINT4 *nsamples, UINT8 *header
 	  goto failed;
   }
 
-  if (!is_valid_detector(rawheader.detector))
+  if (!XLALIsValidCWDetector(rawheader.detector))
   {
 	  XLALPrintError("\nIllegal detector-name in SFT: '%c%c'\n\n",
 		  rawheader.detector[0], rawheader.detector[1]);
@@ -1463,58 +1462,3 @@ calc_crc64(const CHAR *data, UINT4 length, UINT8 crc)
 	return crc;
 
 } /* calc_crc64() */
-
-/* check that channel-prefix defines a 'known' detector.  The list of
-* known detectors implemented here for now follows the list in
-* Appendix D of LIGO-T970130-F-E:
-*
-* returns TRUE if valid, FALSE otherwise */
-static BOOLEAN
-is_valid_detector(const char *channel)
-{
-	int i;
-	const char *knownDetectors[] =
-	{
-		"A1",       /* ALLEGRO */
-		"B1",       /* NIOBE */
-		"E1",       /* EXPLORER */
-		"G1",       /* GEO_600 */
-		"H1",       /* LHO_4k */
-		"H2",       /* LHO_2k */
-		"K1",       /* ACIGA */
-		"L1",       /* LLO_4k */
-		"N1",       /* Nautilus */
-		"O1",       /* AURIGA */
-		"P1",       /* CIT_40 */
-		"T1",       /* TAMA_300 */
-		"V1",       /* Virgo_CITF */
-		"V2",       /* Virgo (3km) */
-		"Z1",	  /* LISA effective IFO 1 */
-		"Z2",	  /* LISA effective IFO 2 */
-		"Z3",	  /* LISA effective IFO 3 */
-		"Z4",	  /* LISA effective IFO 2 minus 3 */
-		"Z5",	  /* LISA effective IFO 3 minus 1 */
-		"Z6",	  /* LISA effective IFO 1 minus 2 */
-		"Z7",	  /* LISA pseudo TDI A */
-		"Z8",	  /* LISA pseudo TDI E */
-		"Z9",	  /* LISA pseudo TDI T */
-		"X1",       /* RXTE PCA */
-		"X2",       /* RXTE ASM */
-		NULL
-	};
-
-	if (!channel)
-		return FALSE;
-
-	if (strlen(channel) < 2)
-		return FALSE;
-
-	for (i = 0; knownDetectors[i]; i++)
-	{
-		if ((knownDetectors[i][0] == channel[0]) && (knownDetectors[i][1] == channel[1]))
-			return TRUE;
-	}
-
-	return FALSE;
-
-} /* is_valid_detector() */
