@@ -149,7 +149,7 @@ int main(int argc,char *argv[])
     exit (1);
   }
 
-  XLAL_CHECK_MAIN ( (VCSInfoString = XLALGetVersionString(0)) != NULL, XLAL_EFUNC );
+  XLAL_CHECK_MAIN ( (VCSInfoString = XLALVCSInfoString(lalAppsVCSInfoList, 0, "%% ")) != NULL, XLAL_EFUNC );
 
   /* Initialize code-setup */
   XLAL_CHECK_MAIN ( InitPFS ( &GV, &uvar ) == XLAL_SUCCESS, XLAL_EFUNC );
@@ -225,10 +225,10 @@ initUserVars ( UserInput_t *uvar )
   XLAL_CHECK ( uvar != NULL, XLAL_EINVAL );
 
   /* set a few defaults */
-  uvar->RngMedWindow = 50;	/* for running-median */
+  uvar->RngMedWindow = FstatOptionalArgsDefaults.runningMedianWindow;
 
-  uvar->ephemEarth = XLALStringDuplicate("earth00-19-DE405.dat.gz");
-  uvar->ephemSun = XLALStringDuplicate("sun00-19-DE405.dat.gz");
+  uvar->ephemEarth = XLALStringDuplicate("earth00-40-DE405.dat.gz");
+  uvar->ephemSun = XLALStringDuplicate("sun00-40-DE405.dat.gz");
 
   uvar->outputFstat = NULL;
   uvar->printFstat = 1;
@@ -325,13 +325,13 @@ InitPFS ( ConfigVariables *cfg, UserInput_t *uvar )
     /* ----- internally we always use h0, cosi */
     if ( have_h0 )
       {
-        cfg->pap.h0=uvar->h0;
-        cfg->pap.cosi=uvar->cosi;
+        cfg->pap.aPlus = 0.5 * uvar->h0 * (1.0 + SQ(uvar->cosi));
+        cfg->pap.aCross = uvar->h0 * uvar->cosi;
       }
     else
       {
-        cfg->pap.h0 = uvar->aPlus + sqrt( SQ( uvar->aPlus ) - SQ( uvar->aCross ) );
-        cfg->pap.cosi= uvar->aCross / cfg->pap.h0;
+        cfg->pap.aPlus = uvar->aPlus;
+        cfg->pap.aCross = uvar->aCross;
       }
     cfg->pap.psi=uvar->psi;
     cfg->pap.phi0=uvar->phi0;
@@ -536,7 +536,7 @@ InitPFS ( ConfigVariables *cfg, UserInput_t *uvar )
   {
     struct tm utc;
     time_t tp;
-    CHAR dateStr[512], line[512], summary[1024];
+    CHAR dateStr[512], line[1024], summary[2048];
     tp = time(NULL);
     sprintf (summary, "%%%% Date: %s", asctime( gmtime( &tp ) ) );
     strcat (summary, "%% Loaded SFTs: [ " );
@@ -547,7 +547,7 @@ InitPFS ( ConfigVariables *cfg, UserInput_t *uvar )
     utc = *XLALGPSToUTC( &utc, (INT4)XLALGPSGetREAL8(&startTime) );
     strcpy ( dateStr, asctime(&utc) );
     dateStr[ strlen(dateStr) - 1 ] = 0;
-    sprintf (line, "%%%% Start GPS time tStart = %12.3f    (%s GMT)\n", XLALGPSGetREAL8(&startTime), dateStr);
+    snprintf (line, sizeof(line), "%%%% Start GPS time tStart = %12.3f    (%s GMT)\n", XLALGPSGetREAL8(&startTime), dateStr);
     strcat ( summary, line );
     sprintf (line, "%%%% Total amount of data: Tdata = %12.3f s  (%.2f days)\n", Tdata, Tdata/86400 );
     strcat ( summary, line );
