@@ -167,7 +167,6 @@ int main(int argc,char *argv[]);
 int XLALInitUserVars ( UserInput_t *uvar );
 int XLALInitCode ( ConfigVariables *cfg, const UserInput_t *uvar );
 int XLALInitAmplitudePrior ( AmplitudePrior_t *AmpPrior, const UserInput_t *uvar );
-MultiLIGOTimeGPSVector * XLALCreateMultiLIGOTimeGPSVector ( UINT4 numDetectors );
 int write_BSGL_candidate_to_fp ( FILE *fp, const BSGLComponents *stats, const LALStringVector *IFOs, const InjParams_t *injParams, const BOOLEAN haveBSGL );
 MultiNoiseWeights * XLALComputeConstantMultiNoiseWeightsFromNoiseFloor (const MultiNoiseFloor *multiNoiseFloor, const MultiLIGOTimeGPSVector *multiTS, const UINT4 Tsft );
 
@@ -409,8 +408,8 @@ XLALInitUserVars ( UserInput_t *uvar )
   uvar->dataStartGPS = 814838413;	/* 1 Nov 2005, ~ start of S5 */
   uvar->dataDuration = (INT4) round ( LAL_YRSID_SI ) ;	/* 1 year of data */
 
-  uvar->ephemEarth = XLALStringDuplicate("earth00-19-DE405.dat.gz");
-  uvar->ephemSun = XLALStringDuplicate("sun00-19-DE405.dat.gz");
+  uvar->ephemEarth = XLALStringDuplicate("earth00-40-DE405.dat.gz");
+  uvar->ephemSun = XLALStringDuplicate("sun00-40-DE405.dat.gz");
 
   uvar->numDraws = 1;
   uvar->TAtom = 1800;
@@ -498,8 +497,8 @@ XLALInitCode ( ConfigVariables *cfg, const UserInput_t *uvar )
 {
   /* generate log-string for file-output, containing cmdline-options + code VCS version info */
   char *vcs;
-  if ( (vcs = XLALGetVersionString(0)) == NULL ) {	  /* short VCS version string */
-    XLALPrintError ( "%s: XLALGetVersionString(0) failed with errno=%d.\n", __func__, xlalErrno );
+  if ( (vcs = XLALVCSInfoString(lalAppsVCSInfoList, 0, "%% ")) == NULL ) {	  /* short VCS version string */
+    XLALPrintError ( "%s: XLALVCSInfoString failed with errno=%d.\n", __func__, xlalErrno );
     XLAL_ERROR ( XLAL_EFUNC );
   }
   char *cmdline;
@@ -750,31 +749,6 @@ XLALInitAmplitudePrior ( AmplitudePrior_t *AmpPrior, const UserInput_t *uvar )
 } /* XLALInitAmplitudePrior() */
 
 
-/**
- * Simple creator function for MultiLIGOTimeGPSVector with numDetectors entries
- */
-MultiLIGOTimeGPSVector *
-XLALCreateMultiLIGOTimeGPSVector ( UINT4 numDetectors )
-{
-  MultiLIGOTimeGPSVector *ret;
-
-  if ( (ret = XLALMalloc ( sizeof(*ret) )) == NULL ) {
-    XLALPrintError ("%s: XLALMalloc(%zu) failed.\n", __func__, sizeof(*ret) );
-    XLAL_ERROR_NULL ( XLAL_ENOMEM );
-  }
-
-  ret->length = numDetectors;
-  if ( (ret->data = XLALCalloc ( numDetectors, sizeof(*ret->data) )) == NULL ) {
-    XLALPrintError ("%s: XLALCalloc(%d, %zu) failed.\n", __func__, numDetectors, sizeof(*ret->data) );
-    XLALFree ( ret );
-    XLAL_ERROR_NULL ( XLAL_ENOMEM );
-  }
-
-  return ret;
-
-} /* XLALCreateMultiLIGOTimeGPSVector() */
-
-
 /**
  * Write one line for given BSGL candidate into output file.
  *
