@@ -31,21 +31,6 @@
 #include <lal/LALStdio.h>
 #include <lal/LogPrintf.h>
 #include <lalapps.h>
-
-#if defined(USE_BOINC) || defined(EAH_BOINC)
-#include "hs_boinc_options.h"
-#ifdef _WIN32
-#include "win_lib.h" // for eah_rename()
-/* On MS Windows boinc_rename() is not as atomic as rename()
-   on POSIX systems. We therefore use our own implementation
-   eah_rename (in win_lib.h) */
-#define rename eah_rename
-#else  // _WIN32
-#include "boinc/filesys.h"
-#define rename boinc_rename
-#endif // _WIN32
-#endif // _BOINC
-
 #include <lal/LogPrintf.h>
 
 /* Windows specifics */
@@ -353,13 +338,7 @@ static int print_gctFstatline_to_str(GCTtopOutputEntry fline, char* buf, int buf
   int len;
   if (fline.have_f3dot){
   len = snprintf(buf, buflen,
-#ifdef EAH_BOINC /* for S5GC1HF Apps use exactly the precision used in the workunit generator
-		    (12g for Freq and F1dot) and skygrid file (7f for Alpha & Delta)
-		    as discussed with Holger & Reinhard 5.11.2010 */
-                     "%.16f %.7f %.7f %.12g %.12g %.12g %d %.6f%s%s%s%s%s\n",
-#else
                      "%.16g %.13g %.13g %.13g %.13g %.13g %d %.6f%s%s%s%s%s\n",
-#endif
                      fline.Freq,
                      fline.Alpha,
                      fline.Delta,
@@ -377,13 +356,7 @@ static int print_gctFstatline_to_str(GCTtopOutputEntry fline, char* buf, int buf
   }
   else {
   len = snprintf(buf, buflen,
-#ifdef EAH_BOINC /* for S5GC1HF Apps use exactly the precision used in the workunit generator
-		    (12g for Freq and F1dot) and skygrid file (7f for Alpha & Delta)
-		    as discussed with Holger & Reinhard 5.11.2010 */
-                     "%.16f %.7f %.7f %.12g %.12g %d %.6f%s%s%s%s%s\n",
-#else
                      "%.16g %.13g %.13g %.13g %.13g %d %.6f%s%s%s%s%s\n",
-#endif
                      fline.Freq,
                      fline.Alpha,
                      fline.Delta,
@@ -532,10 +505,10 @@ static int _atomic_write_gctFstat_toplist_to_file(toplist_t *l, const char *file
     LogPrintf (LOG_CRITICAL, "Could not allocate new filename\n");
     return(-1);
   }
-  strncpy(tempname,filename,s);
-  strncat(tempname,TEMP_EXT,s);
+  strcpy(tempname,filename);
+  strcat(tempname,TEMP_EXT);
 
-  fpnew=LALFopen(tempname, "wb");
+  fpnew=fopen(tempname, "wb");
   if(!fpnew) {
     LogPrintf (LOG_CRITICAL, "Failed to open temp gctFstat file \"%s\" for writing: %d: %s\n",
 	       tempname,errno,strerror(errno));
@@ -552,8 +525,8 @@ static int _atomic_write_gctFstat_toplist_to_file(toplist_t *l, const char *file
     CHAR *VCSInfoString;
 
     /* write the version string */
-    if ( (VCSInfoString = XLALGetVersionString(0)) == NULL ) {
-      LogPrintf (LOG_CRITICAL, "XLALGetVersionString(0) failed.\n");
+    if ( (VCSInfoString = XLALVCSInfoString(lalAppsVCSInfoList, 0, "%% ")) == NULL ) {
+      LogPrintf (LOG_CRITICAL, "XLALVCSInfoString failed.\n");
       length = -1;
     } else {
       ret = fprintf(fpnew,"%s", VCSInfoString);
@@ -564,14 +537,6 @@ static int _atomic_write_gctFstat_toplist_to_file(toplist_t *l, const char *file
 	length += ret;
     }
 
-    /* write BOINC user & host info */
-#ifdef EAH_BOINC
-    fprintf(fpnew,"%%%% UserID: %d\n", eah_userid);
-    fprintf(fpnew,"%%%% Username: '%s'\n", eah_username);
-    fprintf(fpnew,"%%%% HostID: %d\n", eah_hostid);
-    fprintf(fpnew,"%%%% HostCPID: '%s'\n", eah_hostcpid);
-#endif
-
     /* write the command-line */
     if (length >= 0) {
       for(a=0;a<global_argc;a++) {
@@ -718,7 +683,7 @@ int write_gct_checkpoint(const char*filename, toplist_t*tl, toplist_t*t2, toplis
   strncat(tmpfilename,TMP_EXT,len);
 
   /* open tempfile */
-  fp=LALFopen(tmpfilename,"wb");
+  fp=fopen(tmpfilename,"wb");
   if(!fp) {
     LOGIOERROR("Couldn't open",tmpfilename);
     LALFree(tmpfilename);
@@ -938,7 +903,7 @@ int read_gct_checkpoint(const char*filename, toplist_t*tl, toplist_t*t2, toplist
   }
 
   /* try to open file */
-  fp = LALFopen(filename, "rb");
+  fp = fopen(filename, "rb");
   if(!fp) {
     if(errno == ENOENT) {
       LogPrintf(LOG_NORMAL,"INFO: No checkpoint %s found - starting from scratch\n", filename);
