@@ -23,16 +23,14 @@
 from __future__ import print_function, division
 
 #standard library imports
-import sys
+import argparse
+import ast
+import json
+import datetime
 import os
 import re
-import shutil
-import datetime
-import json
-import argparse
-from ConfigParser import ConfigParser
-import subprocess as sp
-import ast
+import sys
+from six.moves.configparser import ConfigParser
 
 #related third party imports
 import numpy as np
@@ -41,13 +39,13 @@ import matplotlib
 matplotlib.use("Agg")
 
 #local application/library specific imports
-from pylal import git_version
+from lalapps import git_version
 from lalapps.pulsarpputils import *
 from lalapps.pulsarhtmlutils import *
 
-__author__="Matthew Pitkin <matthew.pitkin@ligo.org>"
-__version__= "git id %s"%git_version.id
-__date__= git_version.date
+__author__ = "Matthew Pitkin <matthew.pitkin@ligo.org>"
+__version__ = "git id {}".format(git_version.id)
+__date__ = git_version.date
 
 
 # create format for the output page
@@ -205,7 +203,7 @@ parameters = ['f0rot', 'ra', 'dec'] # a list of pulsar parameters to output (def
     sys.exit(1)
 
   resultsdata = {} # dictionary to hold results data
-  sourcedirs = [os.path.join(inpath, rd) for rd in resdirs if os.path.isdir(os.path.join(inpath, rd))]
+  sourcedirs = [os.path.join(inpath, rd) for rd in resdirs if os.path.isfile(os.path.join(inpath, rd, '{}.ini'.format(rd)))]
   totalsources = len(sourcedirs)
   cursources = 0 # currently number of completed sources
   for d in sourcedirs:
@@ -323,7 +321,7 @@ parameters = ['f0rot', 'ra', 'dec'] # a list of pulsar parameters to output (def
     datastyle = "border-bottom:1px solid #000" # style for first value
     for ol in outputlims:
       if ol[-2:] == 'UL': # if value is an upper limit add credible region
-        cr = resultsdata.values()[0][ifo]['Upper limits']['credible region']
+        cr = list(resultsdata.values())[0][ifo]['Upper limits']['credible region']
         restable.adddata(paramhtmldict[ol].format(cr), dataclass=dataclass, datastyle=datastyle, header=True)
         ltable.adddata(paramlatexdict[ol].format(cr))
       else:
