@@ -281,7 +281,7 @@ void setup_lookup_tables( LALInferenceRunState *runState, LALSource *source ){
   ProcessParamsTable *ppt;
   ProcessParamsTable *commandLine = runState->commandLine;
   /* Single thread here */
-  LALInferenceThreadState *threadState = runState->threads[0];
+  LALInferenceThreadState *threadState = &runState->threads[0];
 
   LALInferenceIFOData *data = runState->data;
   LALInferenceIFOModel *ifo_model = threadState->model->ifo;
@@ -416,6 +416,19 @@ void add_initial_variables( LALInferenceVariables *ini, PulsarParameters *pars )
   add_variable_parameter( pars, ini, "HVECTORY", LALINFERENCE_PARAM_FIXED );
   add_variable_parameter( pars, ini, "PSIVECTOR", LALINFERENCE_PARAM_FIXED );
   add_variable_parameter( pars, ini, "PHI0VECTOR", LALINFERENCE_PARAM_FIXED );
+  add_variable_parameter( pars, ini, "HPLUS_F", LALINFERENCE_PARAM_FIXED );
+  add_variable_parameter( pars, ini, "HCROSS_F", LALINFERENCE_PARAM_FIXED );
+  add_variable_parameter( pars, ini, "PSITENSOR_F", LALINFERENCE_PARAM_FIXED );
+  add_variable_parameter( pars, ini, "PHI0TENSOR_F", LALINFERENCE_PARAM_FIXED );
+  add_variable_parameter( pars, ini, "HSCALARB_F", LALINFERENCE_PARAM_FIXED );
+  add_variable_parameter( pars, ini, "HSCALARL_F", LALINFERENCE_PARAM_FIXED );
+  add_variable_parameter( pars, ini, "PSISCALAR_F", LALINFERENCE_PARAM_FIXED );
+  add_variable_parameter( pars, ini, "PHI0SCALAR_F", LALINFERENCE_PARAM_FIXED );
+  add_variable_parameter( pars, ini, "HVECTORX_F", LALINFERENCE_PARAM_FIXED );
+  add_variable_parameter( pars, ini, "HVECTORY_F", LALINFERENCE_PARAM_FIXED );
+  add_variable_parameter( pars, ini, "PSIVECTOR_F", LALINFERENCE_PARAM_FIXED );
+  add_variable_parameter( pars, ini, "PHI0VECTOR_F", LALINFERENCE_PARAM_FIXED );
+  add_variable_parameter( pars, ini, "H0_F", LALINFERENCE_PARAM_FIXED );
 
   /* sky position */
   REAL8 ra = 0.;
@@ -529,7 +542,7 @@ void add_initial_variables( LALInferenceVariables *ini, PulsarParameters *pars )
  *   - "uniform": A flat distribution between a minimum and maximum range (with zero probabiility outside that range);
  *   - "gaussian": A Gaussian/Normal distribution defined by a mean and standard devaition;
  *   - "fermidirac": A Fermi-Dirac-like distribution defined by a knee and attenuation width;
- *   - "gmm": A one-dimensional Gaussian Mixture model defined by the means, standard deviations and weights of each mode.
+ *   - "gmm": A one- or more-dimensional Gaussian Mixture model defined by the means, standard deviations and weights of each mode.
  *   - "loguniform": A flat distribution in log-space (proportional to the inverse of the value in non-log-space)
  * For all priors the first two columns of the prior definition should be:
  *   -# the name of a parameter to be searched over, and
@@ -538,10 +551,12 @@ void add_initial_variables( LALInferenceVariables *ini, PulsarParameters *pars )
  *   -# the lower limit ("uniform" and "loguniform"), mean ("gaussian"), or sigma ("fermidirac") of the distribution;
  *   -# the upper limit ("uniform" and "loguniform"), standard deviation ("gaussian"), or r ("fermidirac") of the distribution.
  * For the "gmm" prior the file should contain at least a further four columns. The third column gives the number of modes
- * for the mixture. For each mode there should then be a tuple of numbers giving the mean, standard deviation and weight
- * of each mode (weights can be relative weights as they will be normalised when parsed by the code). Finally, there can
- * be two additional columns giving lower and upper limits of the distribution (note that the weights given are weights
- * assuming that there are no bounds on the distributions).
+ * for the mixture. The fourth columns is a list of means for each mode (with sub-lists of means
+ * for each parameter). The fifth column is a list of covariance matrices for each mode. The sixth
+ * column is a list of weights for each mode (weights can be relative weights as they will be
+ * normalised when parsed by the code). Finally, there can be additional lists containing pairs
+ * of values for each parameter giving lower and upper limits of the distribution (note that the 
+ * weights given are weights assuming that there are no bounds on the distributions).
  *
  * Some examples of files are:
  * \code
@@ -559,7 +574,7 @@ void add_initial_variables( LALInferenceVariables *ini, PulsarParameters *pars )
  * \endcode
  * or
  * \code
- * H0 gmm 3 1e-25 2e-24 1.5 2e-25 3e-24 2.5 1e-26 1e-25 0.2 0.0 1e-20
+ * H0 gmm 3 [[1e-25],[2e-25],[1e-26]] [[[2e-24]],[[3e-24]],[[1e-25]]] [1.5,2.5,0.2] [0.0,1e-20]
  * PHI0 uniform 0 3.14159265359
  * COSIOTA uniform -1 1
  * PSI uniform -0.785398163397448 0.785398163397448
@@ -578,7 +593,7 @@ void initialise_prior( LALInferenceRunState *runState )
 {
   CHAR *propfile = NULL;
   /* Single thread here */
-  LALInferenceThreadState *threadState = runState->threads[0];
+  LALInferenceThreadState *threadState = &runState->threads[0];
   ProcessParamsTable *ppt;
   ProcessParamsTable *commandLine = runState->commandLine;
 
@@ -598,11 +613,7 @@ void initialise_prior( LALInferenceRunState *runState )
   LALStringVector *corParams = NULL;
   REAL8Array *corMat = NULL;
 
-  INT4 varyphase = 0, varyskypos = 0, varybinary = 0;
-
-  /* check if non-GR parameters are going to be used */
-  UINT4 nonGR = 0;
-  if ( LALInferenceGetProcParamVal( commandLine, "--nonGR" ) ){ nonGR = 1; }
+  INT4 varyphase = 0, varyskypos = 0, varybinary = 0, varyglitch = 0;
 
   ppt = LALInferenceGetProcParamVal( commandLine, "--prior-file" );
   if( ppt ) { propfile = XLALStringDuplicate( LALInferenceGetProcParamVal(commandLine,"--prior-file")->value ); }
@@ -748,10 +759,12 @@ void initialise_prior( LALInferenceRunState *runState )
           TokenList *minmaxvals = NULL;
           XLALCreateTokenList( &minmaxvals, strpart, "," );
           if ( minmaxvals->nTokens == 2 ){
-            if ( isfinite(atof(minmaxvals->tokens[0])) && isfinite(atof(minmaxvals->tokens[1])) ){
+            if ( isfinite(atof(minmaxvals->tokens[0])) ){
               thismin = atof(minmaxvals->tokens[0]);
-              thismax = atof(minmaxvals->tokens[1]);
             }
+            if ( isfinite(atof(minmaxvals->tokens[1])) ){
+	      thismax = atof(minmaxvals->tokens[1]);
+	    }
           }
           XLALDestroyTokenList( minmaxvals );
         }
@@ -791,6 +804,14 @@ void initialise_prior( LALInferenceRunState *runState )
         }
       }
 
+      /* check is there are any glitch parameters that will be searched over */
+      for ( i = 0; i < NUMGLITCHPARS; i++ ){
+        if ( !strncmp(parnames->tokens[j], glitchpars[i], strlen(glitchpars[i]) * sizeof(CHAR)) ){
+          varyglitch = 1;
+          break;
+        }
+      }
+
       /* set variable type to LINEAR (as they are initialised as FIXED) */
       varyType = LALINFERENCE_PARAM_LINEAR;
       LALInferenceSetParamVaryType( threadState->currentParams, parnames->tokens[j], varyType );
@@ -809,19 +830,11 @@ void initialise_prior( LALInferenceRunState *runState )
     if( varyphase ) { LALInferenceAddVariable( ifotemp->params, "varyphase", &varyphase, LALINFERENCE_INT4_t, LALINFERENCE_PARAM_FIXED ); }
     if( varyskypos ) { LALInferenceAddVariable( ifotemp->params, "varyskypos", &varyskypos, LALINFERENCE_INT4_t, LALINFERENCE_PARAM_FIXED ); }
     if( varybinary ) { LALInferenceAddVariable( ifotemp->params, "varybinary", &varybinary, LALINFERENCE_INT4_t, LALINFERENCE_PARAM_FIXED ); }
+    if( varyglitch ) { LALInferenceAddVariable( ifotemp->params, "varyglitch", &varyglitch, LALINFERENCE_INT4_t, LALINFERENCE_PARAM_FIXED ); }
 
     ifotemp = ifotemp->next;
   }
 
-  if ( !LALInferenceGetProcParamVal(commandLine, "--test-gaussian-likelihood" ) ){
-    REAL8Vector *freqFactors = *(REAL8Vector **)LALInferenceGetVariable( ifo->params, "freqfactors" );
-
-    if ( nonGR && freqFactors->length != 1 && freqFactors->data[0] != 2. ){
-      fprintf(stderr, "Error... currently can only run with non-GR parameters for l=m=2 harmonic!\n");
-      exit(3);
-    }
-  }
-
   /* now check for a parameter correlation coefficient matrix file */
   ppt = LALInferenceGetProcParamVal( runState->commandLine, "--cor-file" );
   if( ppt ){
@@ -892,7 +905,7 @@ void initialise_proposal( LALInferenceRunState *runState ){
   }
 
   /* Single thread here */
-  LALInferenceThreadState *threadState = runState->threads[0];
+  LALInferenceThreadState *threadState = &runState->threads[0];
   threadState->cycle = LALInferenceInitProposalCycle();
   LALInferenceProposalCycle *cycle=threadState->cycle;
   /* add proposals */
@@ -1043,7 +1056,7 @@ void add_correlation_matrix( LALInferenceVariables *ini, LALInferenceVariables *
  */
 void sum_data( LALInferenceRunState *runState ){
   LALInferenceIFOData *data = runState->data;
-  LALInferenceIFOModel *ifomodel = runState->threads[0]->model->ifo;
+  LALInferenceIFOModel *ifomodel = runState->threads[0].model->ifo;
 
   UINT4 gaussianLike = 0, roq = 0, nonGR = 0;
 
@@ -1619,7 +1632,7 @@ void initialise_threads(LALInferenceRunState *state, INT4 nthreads){
   INT4 i,randomseed;
   LALInferenceThreadState *thread;
   for (i=0; i<nthreads; i++){
-    thread=state->threads[i];
+    thread=&state->threads[i];
     //LALInferenceCopyVariables(thread->model->params, thread->currentParams);
     LALInferenceCopyVariables(state->priorArgs, thread->priorArgs);
     LALInferenceCopyVariables(state->proposalArgs, thread->proposalArgs);
