@@ -151,7 +151,7 @@ void generate_interpolant( LALInferenceRunState *runState ){
   /* check if using a Gaussian likelihoodm and therefore need variance weighted ROQ values */
   if ( LALInferenceGetProcParamVal( runState->commandLine, "--gaussian-like" ) ){ gaussianLike = 1; }
 
-  ifo = runState->threads[0]->model->ifo;
+  ifo = runState->threads[0].model->ifo;
 
   /* we need to get the frequency factors */
   REAL8Vector *freqFactors = *(REAL8Vector**)LALInferenceGetVariable( ifo->params, "freqfactors" );
@@ -176,11 +176,11 @@ void generate_interpolant( LALInferenceRunState *runState ){
     /* create a copy of the model vector */
     LIGOTimeGPS gpstime = {0, 0};
     REAL8Vector *sidDayFrac = *(REAL8Vector**)LALInferenceGetVariable( ifo->params, "siderealDay" );
-    REAL8Vector *ssbdelays = NULL, *bsbdelays = NULL;
+    REAL8Vector *ssbdelays = NULL, *bsbdelays = NULL, *glitchphase = NULL;
 
     LIGOTimeGPSVector *timenodes = NULL;
     REAL8Vector *sidtimenodes = NULL;
-    REAL8Vector *ssbnodes = NULL, *bsbnodes = NULL;
+    REAL8Vector *ssbnodes = NULL, *bsbnodes = NULL, *gpnodes = NULL;
 
     data->roq = XLALMalloc(sizeof(LALInferenceROQData));
 
@@ -188,6 +188,9 @@ void generate_interpolant( LALInferenceRunState *runState ){
     if ( LALInferenceCheckVariable( ifo->params, "bsb_delays") ){
       bsbdelays = *(REAL8Vector**)LALInferenceGetVariable( ifo->params, "bsb_delays" );
     }
+    if ( LALInferenceCheckVariable( ifo->params, "glitch_phase" ) ){
+      glitchphase = *(REAL8Vector**)LALInferenceGetVariable( ifo->params, "glitch_phase" );
+    }
 
     if ( inputroq ) {
       /* we assume that the data has been split into the same number and length chunks as in that
@@ -223,11 +226,11 @@ void generate_interpolant( LALInferenceRunState *runState ){
         LALInferenceIFOModel *ifotmp = XLALMalloc(sizeof(LALInferenceIFOModel));
         ifotmp->next = NULL;
         tmpRS->threads = LALInferenceInitThreads(1);
-        tmpRS->threads[0]->model = XLALMalloc(sizeof(LALInferenceModel));
-        tmpRS->threads[0]->model->templt = runState->threads[0]->model->templt;
-        LALInferenceClearVariables(tmpRS->threads[0]->currentParams); /* free memory as LALInferenceInitThreads already has allocated memory */
-        tmpRS->threads[0]->currentParams = runState->threads[0]->currentParams;
-        tmpRS->threads[0]->model->ifo = ifotmp;
+        tmpRS->threads[0].model = XLALMalloc(sizeof(LALInferenceModel));
+        tmpRS->threads[0].model->templt = runState->threads[0].model->templt;
+        LALInferenceClearVariables(tmpRS->threads[0].currentParams); /* free memory as LALInferenceInitThreads already has allocated memory */
+        tmpRS->threads[0].currentParams = runState->threads[0].currentParams;
+        tmpRS->threads[0].model->ifo = ifotmp;
         tmpRS->GSLrandom = runState->GSLrandom;
         tmpRS->priorArgs = runState->priorArgs;
         tmpRS->prior = runState->prior;
@@ -258,17 +261,25 @@ void generate_interpolant( LALInferenceRunState *runState ){
           LALInferenceRemoveVariable( ifotmp->params, "bsb_delays" );
         }
 
+        REAL8Vector *thisglitchphase = NULL;
+        if ( glitchphase != NULL ){
+          thisglitchphase = XLALCreateREAL8Vector( tlen );
+          LALInferenceRemoveVariable( ifotmp->params, "glitch_phase" );
+        }
+
         /* get chunk times */
         for ( j=0; j<tlen; j++ ){
           ifotmp->times->data[j] = ifo->times->data[startidx+j];
           thissiddayfrac->data[j] = sidDayFrac->data[startidx+j];
           thisssbdelay->data[j] = ssbdelays->data[startidx+j];
           if ( bsbdelays != NULL ){ thisbsbdelay->data[j] = bsbdelays->data[startidx+j]; }
+          if ( glitchphase != NULL ){ thisglitchphase->data[j] = glitchphase->data[startidx+j]; }
         }
 
         LALInferenceAddVariable( ifotmp->params, "siderealDay", &thissiddayfrac, LALINFERENCE_REAL8Vector_t, LALINFERENCE_PARAM_FIXED );
         LALInferenceAddVariable( ifotmp->params, "ssb_delays", &thisssbdelay, LALINFERENCE_REAL8Vector_t, LALINFERENCE_PARAM_FIXED );
         if ( bsbdelays != NULL ){ LALInferenceAddVariable( ifotmp->params, "bsb_delays", &thisbsbdelay, LALINFERENCE_REAL8Vector_t, LALINFERENCE_PARAM_FIXED ); }
+        if ( glitchphase != NULL ){ LALInferenceAddVariable( ifotmp->params, "glitch_phase", &thisglitchphase, LALINFERENCE_REAL8Vector_t, LALINFERENCE_PARAM_FIXED ); }
 
         REAL8Vector *deltas = XLALCreateREAL8Vector( 1 );
         deltas->data[0] = dt;
@@ -446,7 +457,7 @@ void generate_interpolant( LALInferenceRunState *runState ){
         XLALDestroyTimestampVector( ifotmp->times );
         XLALDestroyCOMPLEX16TimeSeries( ifotmp->compTimeSignal );
         LALInferenceClearVariables( ifotmp->params );
-        XLALFree( tmpRS->threads[0]->model );
+        XLALFree( tmpRS->threads[0].model );
         XLALFree( tmpRS->threads );
         XLALFree( tmpRS );
 
@@ -572,12 +583,14 @@ void generate_interpolant( LALInferenceRunState *runState ){
       sidtimenodes = XLALResizeREAL8Vector( sidtimenodes, tnlength );
       ssbnodes = XLALResizeREAL8Vector( ssbnodes, tnlength );
       if ( bsbdelays != NULL ){ bsbnodes = XLALResizeREAL8Vector( bsbnodes, tnlength ); }
+      if ( glitchphase != NULL ){ gpnodes = XLALResizeREAL8Vector( gpnodes, tnlength ); }
 
       for ( j=0; j<nbases0; j++ ){
         timenodes->data[dlen+j] = ifo->times->data[startidx+interp->nodes[j]];
         sidtimenodes->data[dlen+j] = sidDayFrac->data[startidx+interp->nodes[j]];
         ssbnodes->data[dlen+j] = ssbdelays->data[startidx+interp->nodes[j]];
         if ( bsbdelays != NULL ){ bsbnodes->data[dlen+j] = bsbdelays->data[startidx+interp->nodes[j]]; }
+        if ( glitchphase != NULL ){ gpnodes->data[dlen+j] = glitchphase->data[startidx+interp->nodes[j]]; }
       }
 
       dlen += nbases0;
@@ -589,12 +602,14 @@ void generate_interpolant( LALInferenceRunState *runState ){
 
       ssbnodes = XLALResizeREAL8Vector( ssbnodes, tnlength );
       if ( bsbdelays != NULL ){ bsbnodes = XLALResizeREAL8Vector( bsbnodes, tnlength ); }
+      if ( glitchphase != NULL ){ gpnodes = XLALResizeREAL8Vector( gpnodes, tnlength ); }
 
       for ( j=0; j<nbases0quad; j++ ){
         timenodes->data[dlen+j] = ifo->times->data[startidx+interpquad->nodes[j]];
         sidtimenodes->data[dlen+j] = sidDayFrac->data[startidx+interpquad->nodes[j]];
         ssbnodes->data[dlen+j] = ssbdelays->data[startidx+interpquad->nodes[j]];
         if ( bsbdelays != NULL ){ bsbnodes->data[dlen+j] = bsbdelays->data[startidx+interpquad->nodes[j]]; }
+        if ( glitchphase != NULL ){ gpnodes->data[dlen+j] = glitchphase->data[startidx+interpquad->nodes[j]]; }
       }
 
       LALInferenceRemoveCOMPLEXROQInterpolant( interp );
@@ -634,6 +649,14 @@ void generate_interpolant( LALInferenceRunState *runState ){
       LALInferenceAddVariable( ifo->params, "bsb_delays_full", &bsbcopy, LALINFERENCE_REAL8Vector_t, LALINFERENCE_PARAM_FIXED );
     }
 
+    if ( glitchphase != NULL ){
+      REAL8Vector *glitchphasecopy = XLALCreateREAL8Vector( glitchphase->length );
+      memcpy(glitchphasecopy->data, glitchphase->data, sizeof(REAL8)*glitchphase->length);
+      LALInferenceRemoveVariable( ifo->params, "glitch_phase" );
+      LALInferenceAddVariable( ifo->params, "glitch_phase", &gpnodes, LALINFERENCE_REAL8Vector_t, LALINFERENCE_PARAM_FIXED );
+      LALInferenceAddVariable( ifo->params, "glitch_phase_full", &glitchphasecopy, LALINFERENCE_REAL8Vector_t, LALINFERENCE_PARAM_FIXED );
+    }
+
     ifo->compTimeSignal = XLALResizeCOMPLEX16TimeSeries( ifo->compTimeSignal, 0, dmlength+mmlength );
 
     if ( inputroq ){
@@ -659,7 +682,7 @@ void generate_interpolant( LALInferenceRunState *runState ){
     memcpy(data->roq->weightsQuadratic, mmweights, mmlength*sizeof(REAL8));
     XLALFree( mmweights );
 
-    /* add interpolation nodes to a variable in runState->threads[0]->model->ifo->params */
+    /* add interpolation nodes to a variable in runState->threads[0].model->ifo->params */
     LALInferenceAddVariable( ifo->params, "numBases", &nbases, LALINFERENCE_UINT4Vector_t, LALINFERENCE_PARAM_FIXED );
     LALInferenceAddVariable( ifo->params, "numBasesQuad", &nbasesquad, LALINFERENCE_UINT4Vector_t, LALINFERENCE_PARAM_FIXED );
 
@@ -671,7 +694,7 @@ void generate_interpolant( LALInferenceRunState *runState ){
   if( verbose ){ fprintf(stderr, "Total number of linear bases = %d, total number of quadratic bases = %d, total number of data points = %d\n", nlineartot, nquadtot, ndatatot); }
 
   /* reset freqfactors to the correct value */
-  ifo = runState->threads[0]->model->ifo;
+  ifo = runState->threads[0].model->ifo;
   while ( ifo ){
     check_and_add_fixed_variable( ifo->params, "freqfactors", &freqsCopy, LALINFERENCE_REAL8Vector_t );
     ifo = ifo->next;
@@ -716,13 +739,13 @@ COMPLEX16Array *generate_training_set( LALInferenceRunState *rs, UINT4 n ){
   UINT4 j = 0;
   UINT4Vector *dims = XLALCreateUINT4Vector( 2 );
   dims->data[0] = n;
-  dims->data[1] = rs->threads[0]->model->ifo->times->length;
+  dims->data[1] = rs->threads[0].model->ifo->times->length;
   COMPLEX16Array *ts = XLALCreateCOMPLEX16Array( dims );
   gsl_matrix_complex_view tsview = gsl_matrix_complex_view_array( (double *)ts->data, dims->data[0], dims->data[1] );
   XLALDestroyUINT4Vector( dims );
   REAL8 logprior = 0.;
 
-  rs->threads[0]->model->params = XLALCalloc(1, sizeof(LALInferenceVariables));
+  rs->threads[0].model->params = XLALCalloc(1, sizeof(LALInferenceVariables));
 
   /* for parameters with Gaussian priors reset them to be flat, with ranges over +/-5 sigma for training set generation if required */
   LALInferenceVariables *priorcopy = NULL;
@@ -730,7 +753,7 @@ COMPLEX16Array *generate_training_set( LALInferenceRunState *rs, UINT4 n ){
   if( LALInferenceGetProcParamVal( rs->commandLine, "--roq-uniform" ) ){
     priorcopy = XLALCalloc(1, sizeof(LALInferenceVariables));
     LALInferenceCopyVariables( rs->priorArgs, priorcopy );
-    LALInferenceVariableItem *item = rs->threads[0]->currentParams->head;
+    LALInferenceVariableItem *item = rs->threads[0].currentParams->head;
     UINT4 hascorrelated = 0; /* set if there is a correlated prior */
     for( ; item; item = item->next ){
       REAL8 mu = 0., sigma = 0., minval = 0., maxval = 0.;
@@ -756,29 +779,29 @@ COMPLEX16Array *generate_training_set( LALInferenceRunState *rs, UINT4 n ){
     if ( hascorrelated ) { LALInferenceRemoveCorrelatedPrior( rs->priorArgs ); } /* remove correlated prior */
   }
 
-  /* choose random variables values and fill in runState->threads[0]->model->params */
+  /* choose random variables values and fill in runState->threads[0].model->params */
   while ( j < n ){
     /* copy values to model parameters */
-    LALInferenceCopyVariables(rs->threads[0]->currentParams, rs->threads[0]->model->params);
+    LALInferenceCopyVariables(rs->threads[0].currentParams, rs->threads[0].model->params);
 
     /* draw from the prior distributions */
-    LALInferenceDrawFromPrior( rs->threads[0]->model->params, rs->priorArgs, rs->GSLrandom );
+    LALInferenceDrawFromPrior( rs->threads[0].model->params, rs->priorArgs, rs->GSLrandom );
 
     /* check prior is non-zero */
-    logprior = rs->prior(rs, rs->threads[0]->model->params, rs->threads[0]->model);
+    logprior = rs->prior(rs, rs->threads[0].model->params, rs->threads[0].model);
     if ( logprior == -DBL_MAX || logprior == -INFINITY || isnan(logprior) ){ continue; }
 
     /* generate model */
-    rs->threads[0]->model->templt( rs->threads[0]->model );
+    rs->threads[0].model->templt( rs->threads[0].model );
 
     /* place model into an array */
     gsl_vector_complex_view cview;
-    cview = gsl_vector_complex_view_array((double*)rs->threads[0]->model->ifo->compTimeSignal->data->data, rs->threads[0]->model->ifo->times->length);
+    cview = gsl_vector_complex_view_array((double*)rs->threads[0].model->ifo->compTimeSignal->data->data, rs->threads[0].model->ifo->times->length);
     gsl_matrix_complex_set_row(&tsview.matrix, j, &cview.vector);
     j++;
   }
 
-  LALInferenceClearVariables(rs->threads[0]->model->params);
+  LALInferenceClearVariables(rs->threads[0].model->params);
 
   /* reset priors if required */
   if( LALInferenceGetProcParamVal( rs->commandLine, "--roq-uniform" ) ){
@@ -807,20 +830,20 @@ REAL8Array *generate_training_set_quad( LALInferenceRunState *rs, UINT4 n ){
   UINT4 j = 0, k = 0;
   UINT4Vector *dims = XLALCreateUINT4Vector( 2 );
   dims->data[0] = n;
-  dims->data[1] = rs->threads[0]->model->ifo->times->length;
+  dims->data[1] = rs->threads[0].model->ifo->times->length;
   REAL8Array *ts = XLALCreateREAL8Array( dims );
   gsl_matrix_view tsview = gsl_matrix_view_array( ts->data, dims->data[0], dims->data[1] );
   XLALDestroyUINT4Vector( dims );
   REAL8 logprior = 0.;
 
-  rs->threads[0]->model->params = XLALCalloc(1, sizeof(LALInferenceVariables));
+  rs->threads[0].model->params = XLALCalloc(1, sizeof(LALInferenceVariables));
 
   /* for parameters with Gaussian priors reset them to be flat, with ranges over +/-5 sigma for training set generation if required */
   LALInferenceVariables *priorcopy = NULL;
   if( LALInferenceGetProcParamVal( rs->commandLine, "--roq-uniform" ) ){
     priorcopy = XLALCalloc(1, sizeof(LALInferenceVariables));
     LALInferenceCopyVariables( rs->priorArgs, priorcopy );
-    LALInferenceVariableItem *item = rs->threads[0]->currentParams->head;
+    LALInferenceVariableItem *item = rs->threads[0].currentParams->head;
     UINT4 hascorrelated = 0; /* set if there is a correlated prior */
     for( ; item; item = item->next ){
       REAL8 mu = 0., sigma = 0., minval = 0., maxval = 0.;
@@ -846,30 +869,30 @@ REAL8Array *generate_training_set_quad( LALInferenceRunState *rs, UINT4 n ){
     if ( hascorrelated ) { LALInferenceRemoveCorrelatedPrior( rs->priorArgs ); } /* remove correlated prior */
   }
 
-  /* choose random variables values and fill in runState->threads[0]->model->params */
+  /* choose random variables values and fill in runState->threads[0].model->params */
   while ( j < n ){
     /* copy values to model parameters */
-    LALInferenceCopyVariables(rs->threads[0]->currentParams, rs->threads[0]->model->params);
+    LALInferenceCopyVariables(rs->threads[0].currentParams, rs->threads[0].model->params);
 
     /* draw from the prior distributions */
-    LALInferenceDrawFromPrior( rs->threads[0]->model->params, rs->priorArgs, rs->GSLrandom );
+    LALInferenceDrawFromPrior( rs->threads[0].model->params, rs->priorArgs, rs->GSLrandom );
 
     /* check prior is non-zero */
-    logprior = rs->prior(rs, rs->threads[0]->model->params, rs->threads[0]->model);
+    logprior = rs->prior(rs, rs->threads[0].model->params, rs->threads[0].model);
     if ( logprior == -DBL_MAX || logprior == -INFINITY || isnan(logprior) ){ continue; }
 
     /* generate model */
-    rs->threads[0]->model->templt( rs->threads[0]->model );
+    rs->threads[0].model->templt( rs->threads[0].model );
 
     /* place model*model^* into an array */
-    for ( k = 0; k < rs->threads[0]->model->ifo->times->length; k++ ){
-      COMPLEX16 cval = rs->threads[0]->model->ifo->compTimeSignal->data->data[k];
+    for ( k = 0; k < rs->threads[0].model->ifo->times->length; k++ ){
+      COMPLEX16 cval = rs->threads[0].model->ifo->compTimeSignal->data->data[k];
       gsl_matrix_set(&tsview.matrix, j, k, creal(cval*conj(cval)));
     }
     j++;
   }
 
-  LALInferenceClearVariables(rs->threads[0]->model->params);
+  LALInferenceClearVariables(rs->threads[0].model->params);
 
   /* reset priors if required */
   if( LALInferenceGetProcParamVal( rs->commandLine, "--roq-uniform" ) ){
