@@ -73,11 +73,6 @@
 
 #include <lal/LALSimNoise.h>
 
-/* check whether openmp is enabled and if so include omp.h */
-#ifdef HAVE_OPENMP
-#include <omp.h>
-#endif
-
 #include <gsl/gsl_sort_double.h>
 #include <gsl/gsl_statistics_double.h>
 #include <gsl/gsl_blas.h>
@@ -138,7 +133,7 @@ extern "C" {
  *
  * Note: These should be increased if additional model parameters are added.
  */
-#define NUMAMPPARS 28
+#define NUMAMPPARS 29
 
 /**
  * The total number of sky position parameters that can define a signal e.g.
@@ -159,7 +154,7 @@ extern "C" {
 #define NUMGLITCHPARS 7
 
 /** The maximum number of different detectors allowable. */
-#define MAXDETS 6
+#define MAXDETS 10
 
 /** The usage format for the code.  */
 #define USAGE \
@@ -203,6 +198,8 @@ extern "C" {
 " --randomise         Set this, with an INT seed, to randomise the data (through permutations\n\
                      of the time stamps) for use in Monte-Carlo studies. NOTE: this will not\n\
                      work if using the code to create injections\n"\
+" --start-time        (REAL8) only use data after the given GPS start time\n"\
+" --end-time          (REAL8) discard data after the given GPS end time\n"\
 " --truncate-time     maximum GPS time to be analyzed (discards data with larger\n\
                      timestamp)\n"\
 " --truncate-samples  maximum sample number to be analyzed (analyzes only first\n\
@@ -344,7 +341,7 @@ static const CHAR amppars[NUMAMPPARS][VARNAME_MAX] = { "H0", "PHI0", "PSI",
 "COSIOTA", "C22", "C21", "PHI22", "PHI21", "HPLUS", "HCROSS", "HSCALARB",
 "HSCALARL", "HVECTORX", "HVECTORY", "PSIVECTOR", "PHI0VECTOR", "PSISCALAR",
 "PHI0SCALAR", "PSITENSOR", "PHI0TENSOR", "I21", "I31", "LAMBDA", "COSTHETA",
-"IOTA", "THETA", "Q22", "DIST" };
+"IOTA", "THETA", "Q22", "DIST", "H0_F" };
 
 /**
  * A list of the sky position parameters. The names given here are those that
