@@ -102,7 +102,7 @@ LALReadSFTheader (LALStatus  *status,			/**< pointer to LALStatus structure */
   ASSERT (fname,  status, SFTFILEIO_ENULL,  SFTFILEIO_MSGENULL);
 
   /* opening the SFT binary file */
-  fp = LALFopen( fname, "rb" );
+  fp = fopen( fname, "rb" );
   if (fp == NULL) {
     ABORT (status, SFTFILEIO_EFILE,  SFTFILEIO_MSGEFILE);
   }
@@ -252,7 +252,7 @@ LALReadSFTdata(LALStatus *status,			/**< pointer to LALStatus structure */
   offset = fminBinIndex - header.fminBinIndex;
 
   /* open file for reading */
-  if ( (fp = LALFopen( fname, "rb" )) == NULL) {
+  if ( (fp = fopen( fname, "rb" )) == NULL) {
     ABORT (status, SFTFILEIO_EFILE, SFTFILEIO_MSGEFILE);
   }
 
