@@ -32,20 +32,6 @@
 #include <lal/LALStdio.h>
 #include <lal/LogPrintf.h>
 
-#if defined(USE_BOINC) || defined(EAH_BOINC)
-#include "boinc/filesys.h"
-#define fopen boinc_fopen
-#ifdef _WIN32
-/* On MS Windows boinc_rename() is not as atomic as rename()
-   on POSIX systems. We therefore use our own implementation
-   eah_rename (in win_lib.h) */
-extern int eah_rename(const char* oldf, const char* newf);
-#define rename eah_rename
-#else  // _WIN32
-#define rename boinc_rename
-#endif // _WIN32
-#endif // _BOINC
-
 #include <lal/LogPrintf.h>
 
 /* Windows specifics */
@@ -441,8 +427,8 @@ static int _atomic_write_houghFstat_toplist_to_file(toplist_t *l, const char *fi
       LogPrintf (LOG_CRITICAL, "Could not allocate new filename\n");
       return(-1);
     }
-    strncpy(tempname,filename,s);
-    strncat(tempname,TEMP_EXT,s);
+    strcpy(tempname,filename);
+    strcat(tempname,TEMP_EXT);
 
     fpnew=fopen(tempname, "wb");
     if(!fpnew) {
@@ -546,8 +532,8 @@ int write_hfs_checkpoint(const char*filename, toplist_t*tl, UINT4 counter, BOOLE
     LogPrintf(LOG_CRITICAL,"Couldn't allocate tmpfilename\n");
     return(-2);
   }
-  strncpy(tmpfilename,filename,len);
-  strncat(tmpfilename,TMP_EXT,len);
+  strcpy(tmpfilename,filename);
+  strcat(tmpfilename,TMP_EXT);
 
   /* calculate checksum */
   checksum = 0;
