@@ -221,7 +221,6 @@ int XLALFreeMem ( ConfigVars_t *cfg );
 BOOLEAN is_directory ( const CHAR *fname );
 int XLALIsValidDescriptionField ( const char *desc );
 
-static BOOLEAN is_valid_detector (const char *channel);
 void LALWriteSFTfile (LALStatus *, const SFTtype *sft, const CHAR *outfname);
 void LALWrite_v2SFT_to_v1file (LALStatus *, const SFTtype *sft, const CHAR *fname);
 
@@ -255,12 +254,8 @@ main(int argc, char *argv[])
   params.pulsar.position.system    = COORDINATESYSTEM_EQUATORIAL;
   params.pulsar.position.longitude = GV.pulsar.Doppler.Alpha;
   params.pulsar.position.latitude  = GV.pulsar.Doppler.Delta;
-  {
-    REAL8 h0   = GV.pulsar.Amp.h0;
-    REAL8 cosi = GV.pulsar.Amp.cosi;
-    params.pulsar.aPlus		   = 0.5 * h0 * ( 1.0 + SQ(cosi) );
-    params.pulsar.aCross	   = h0 * cosi;
-  }
+  params.pulsar.aPlus		   = GV.pulsar.Amp.aPlus;
+  params.pulsar.aCross         = GV.pulsar.Amp.aCross;
   params.pulsar.phi0		   = GV.pulsar.Amp.phi0;
   params.pulsar.psi 		   = GV.pulsar.Amp.psi;
 
@@ -316,7 +311,7 @@ main(int argc, char *argv[])
       }
 
       /* open concatenated SFT file for writing */
-      if ( (fpSingleSFT = LALFopen ( uvar.outSFTbname, "wb" )) == NULL ) {
+      if ( (fpSingleSFT = fopen ( uvar.outSFTbname, "wb" )) == NULL ) {
         XLAL_ERROR ( XLAL_EIO, "Failed to open file '%s' for writing: %s\n\n", uvar.outSFTbname, strerror(errno));
       }
     } // if outSingleSFT
@@ -567,7 +562,7 @@ main(int argc, char *argv[])
   if ( uvar.outSingleSFT ) {
 
     /* close concatenated SFT */
-    LALFclose( fpSingleSFT );
+    fclose( fpSingleSFT );
 
   }
 
@@ -588,8 +583,8 @@ XLALInitMakefakedata ( ConfigVars_t *cfg, UserVariables_t *uvar )
   XLAL_CHECK ( cfg != NULL, XLAL_EINVAL, "Invalid NULL input 'cfg'\n" );
   XLAL_CHECK ( uvar != NULL, XLAL_EINVAL, "Invalid NULL input 'uvar'\n");
 
-  cfg->VCSInfoString = XLALGetVersionString(0);
-  XLAL_CHECK ( cfg->VCSInfoString != NULL, XLAL_EFUNC, "XLALGetVersionString(0) failed.\n" );
+  cfg->VCSInfoString = XLALVCSInfoString(lalAppsVCSInfoList, 0, "%% ");
+  XLAL_CHECK ( cfg->VCSInfoString != NULL, XLAL_EFUNC, "XLALVCSInfoString failed.\n" );
 
   BOOLEAN have_parfile = XLALUserVarWasSet (&uvar->parfile);
   BinaryPulsarParams pulparams;
@@ -659,26 +654,21 @@ XLALInitMakefakedata ( ConfigVars_t *cfg, UserVariables_t *uvar )
       XLAL_ERROR ( XLAL_EINVAL, "Need BOTH --aPlus and --aCross !\n\n");
     }
     if ( have_h0 && have_cosi )
-      {
-	cfg->pulsar.Amp.h0 = uvar->h0;
-	cfg->pulsar.Amp.cosi = uvar->cosi;
+      {   /* translate {h_0, cosi} into A_{+,x} */
+          /* assume at 2f */
+          REAL8 h0 = uvar->h0;
+          REAL8 cosi = uvar->cosi;
+          cfg->pulsar.Amp.aPlus = 0.5 * h0 * (1.0 + SQ(cosi));
+          cfg->pulsar.Amp.aCross = h0 * cosi;
       }
     else if ( have_aPlus && have_aCross )
-      {  /* translate A_{+,x} into {h_0, cosi} */
-	REAL8 disc;
-	if ( fabs(uvar->aCross) > uvar->aPlus ) {
-          XLAL_ERROR ( XLAL_EINVAL, "Invalid input parameters: |aCross| = %g must be <= than aPlus = %g.\n", fabs(uvar->aCross), uvar->aPlus );
-        }
-	disc = sqrt ( SQ(uvar->aPlus) - SQ(uvar->aCross) );
-	cfg->pulsar.Amp.h0   = uvar->aPlus + disc;
-        if ( cfg->pulsar.Amp.h0 > 0 )
-          cfg->pulsar.Amp.cosi = uvar->aCross / cfg->pulsar.Amp.h0;	// avoid division by 0!
-        else
-          cfg->pulsar.Amp.cosi = 0;
+      {
+          cfg->pulsar.Amp.aPlus = uvar->aPlus;
+          cfg->pulsar.Amp.aCross = uvar->aCross;
       }
     else {
-      cfg->pulsar.Amp.h0 = 0.0;
-      cfg->pulsar.Amp.cosi = 0.0;
+        cfg->pulsar.Amp.aPlus = 0.0;
+        cfg->pulsar.Amp.aCross = 0.0;
     }
     cfg->pulsar.Amp.phi0 = uvar->phi0;
     cfg->pulsar.Amp.psi  = uvar->psi;
@@ -752,12 +742,12 @@ XLALInitMakefakedata ( ConfigVars_t *cfg, UserVariables_t *uvar )
       {
       case 3:
 	cfg->spindown->data[2] = uvar->f3dot;
-#if __GNUC__ >= 7
+#if __GNUC__ >= 7 && !defined __INTEL_COMPILER
 	__attribute__ ((fallthrough));
 #endif
       case 2:
 	cfg->spindown->data[1] = uvar->f2dot;
-#if __GNUC__ >= 7
+#if __GNUC__ >= 7 && !defined __INTEL_COMPILER
 	__attribute__ ((fallthrough));
 #endif
       case 1:
@@ -1198,8 +1188,8 @@ XLALInitUserVars ( UserVariables_t *uvar, int argc, char *argv[] )
   XLAL_CHECK ( argv != NULL, XLAL_EINVAL, "Invalid NULL input 'argv'\n");
 
   // ---------- set a few defaults ----------
-  uvar->ephemEarth = XLALStringDuplicate("earth00-19-DE405.dat.gz");
-  uvar->ephemSun = XLALStringDuplicate("sun00-19-DE405.dat.gz");
+  uvar->ephemEarth = XLALStringDuplicate("earth00-40-DE405.dat.gz");
+  uvar->ephemSun = XLALStringDuplicate("sun00-40-DE405.dat.gz");
 
   uvar->Tsft = 1800;
 
@@ -1251,8 +1241,8 @@ XLALInitUserVars ( UserVariables_t *uvar, int argc, char *argv[] )
   XLALRegisterUvarMember(  Alpha,		 RAJ, 0, OPTIONAL, "Sky: equatorial J2000 right ascension (in radians or hours:minutes:seconds)");
   XLALRegisterUvarMember(  Delta,		 DECJ, 0, OPTIONAL, "Sky: equatorial J2000 declination (in radians or degrees:minutes:seconds)");
 
-  XLALRegisterUvarMember(  h0,                   REAL8, 0, OPTIONAL, "Overall signal-amplitude h0");
-  XLALRegisterUvarMember(  cosi,                 REAL8, 0, OPTIONAL, "cos(iota) of inclination-angle iota");
+  XLALRegisterUvarMember(  h0,                   REAL8, 0, OPTIONAL, "Overall signal-amplitude h0 (for emission at twice spin frequency only)");
+  XLALRegisterUvarMember(  cosi,                 REAL8, 0, OPTIONAL, "cos(iota) of inclination-angle iota (for emission at twice spin frequency only)");
   XLALRegisterUvarMember(  aPlus,                REAL8, 0, OPTIONAL, "ALTERNATIVE to {--h0,--cosi}: A_+ amplitude");
   XLALRegisterUvarMember(  aCross,               REAL8, 0, OPTIONAL, "ALTERNATIVE to {--h0,--cosi}: A_x amplitude");
 
@@ -1509,23 +1499,6 @@ is_directory ( const CHAR *fname )
 #define SFTFILEIO_MSGEVAL       "Invalid value"
 #define SFTFILEIO_MSGEMEM       "Out of memory"
 
-/* check that channel-prefix defines a valid 'known' detector.
- * This is just a convenience wrapper to XLALGetCWDetectorPrefix(), which defines all valid 'CW detectors'
- *
- * returns TRUE if valid, FALSE otherwise */
-static BOOLEAN
-is_valid_detector (const char *channel)
-{
-
-  char *prefix = XLALGetCWDetectorPrefix ( NULL, channel );
-  if ( prefix == NULL ) {
-    return FALSE;
-  }
-  XLALFree ( prefix );
-  return TRUE;
-
-} /* is_valid_detector() */
-
 /**
  * [OBSOLETE] Write a *v1-normalized* (i.e. raw DFT) SFTtype to a SFT-v1 file.
  *
@@ -1613,7 +1586,7 @@ LALWriteSFTfile (LALStatus  *status,			/**< pointer to LALStatus structure */
 
 
   /* open the file for writing */
-  fp = LALFopen(outfname, "wb");
+  fp = fopen(outfname, "wb");
   if (fp == NULL) {
     LALFree (rawheader);
     LALFree (rawdata);
@@ -1679,7 +1652,7 @@ LALWrite_v2SFT_to_v1file (LALStatus *status,			/**< pointer to LALStatus structu
 
   ASSERT (fname, status, SFTFILEIO_ENULL, SFTFILEIO_MSGENULL);
 
-  if ( !is_valid_detector(sft->name) ) {
+  if ( !XLALIsValidCWDetector(sft->name) ) {
     ABORT ( status, SFTFILEIO_EVAL, SFTFILEIO_MSGEVAL );
   }
 
