@@ -6,12 +6,14 @@ Loosely based on lalapps_strain_pipe
 
 """
 
+from __future__ import print_function
+
 __author__ = 'Greg Mendell<gmendell@ligo-wa.caltech.edu>'
 __date__ = '$Date$'
 __version__ = '$Revision$'
 
 # REVISIONS:
-# 12/02/05 gam; generate datafind.sub and MakeSFTs.sub as well as dag file in PWD, with log files based subLogPath and dag filename. 
+# 12/02/05 gam; generate datafind.sub and MakeSFTs.sub as well as dag file in PWD, with log files based subLogPath and dag filename.
 # 12/28/05 gam; Add option --make-gps-dirs, -D <num>, to make directory based on this many GPS digits.
 # 12/28/05 gam; Add option --misc-desc, -X <string> giving misc. part of the SFT description field in the filename.
 # 12/28/05 gam; Add options --start-freq -F and --band -B options to enter these.
@@ -28,8 +30,7 @@ __version__ = '$Revision$'
 
 # import standard modules and append the lalapps prefix to the python path
 import sys, os
-import getopt, re, string
-import tempfile
+import getopt
 import math
 #import ConfigParser
 #sys.path.append('')
@@ -44,10 +45,10 @@ import math
 def usage():
   msg = """\
 
-This script creates datafind.sub, MakeSFTs.sub, and a dag file that generates SFTs based on the options given. 
+This script creates datafind.sub, MakeSFTs.sub, and a dag file that generates SFTs based on the options given.
 
 The script can be used to create dag files for stand-alone use with condor_submit_dag, or as a dag generator with onasys.
-  
+
 Usage: MakeSFTDAG [options]
 
   -h, --help                 display this message
@@ -83,7 +84,7 @@ Usage: MakeSFTDAG [options]
   -L, --max-length-all-jobs  maximum total amount of data to process, in seconds (optional and unused if a segment file is given)
   -g, --segment-file         (optional) alternative file with segments to use, rather than the input times.
   -A, --accounting-group     (optional) accounting group tag to be added to the condor submit files.
-  -U, --accounting-group-user  (optional) accounting group albert.einstein username to be added to the condor submit files.  
+  -U, --accounting-group-user  (optional) accounting group albert.einstein username to be added to the condor submit files.
   -q, --list-of-nodes        (optional) file with list of nodes on which to output SFTs.
   -Q, --node-path            (optional) path to nodes to output SFTs; the node name is appended to this path, followed by path given by the -p option;
                                         for example, if -q point to file with the list node1 node2 ... and the -Q /data/ -p /frames/S5/sfts/LHO options
@@ -94,8 +95,11 @@ Usage: MakeSFTDAG [options]
   -S, --use-single           (optional) use single precision in MakeSFTs for windowing, plan and fft; filtering is always done in double precision. Use of double precision in MakeSFTs is the default.
   -H, --use-hot              (optional) input data is from h(t) calibrated frames (h of t = hot!) (0 or 1).
   -u  --frame-struct-type    (optional) string specifying the input frame structure and data type. Must begin with ADC_ or PROC_ followed by REAL4, REAL8, INT2, INT4, or INT8; default: ADC_REAL4; -H is the same as PROC_REAL8.
+  -j, --datafind-path        (optional) string specifying a path to look for the gw_data_find executable; if not set, will use LSC_DATAFIND_PATH env variable or system default (in that order).
+  -J, --makesfts-path        (optional) string specifying a path to look for the lalapps_MakeSFTs executable; if not set, will use MAKESFTS_PATH env variable or system default (in that order).
+  -Y, --request-memory       (optional) memory allocation in MB to request from condor for lalapps_MakeSFTs step
 """
-  print >> sys.stdout, msg
+  print(msg)
 
 #
 # FUNCTION THAT WRITE ONE JOB TO DAG FILE
@@ -128,13 +132,13 @@ def writeToDag(dagFID, nodeCount, filterKneeFreq, timeBaseline, outputSFTPath, c
   if makeTmpFile: argList = argList + ' -Z'
   dagFID.write('VARS %s argList="%s" tagstring="%s"\n'%(MakeSFTs,argList, tagStringOut))
   dagFID.write('PARENT %s CHILD %s\n'%(LSCdataFind,MakeSFTs))
-  
+
 #
-# MAIN CODE START HERE 
+# MAIN CODE START HERE
 #
 
 # parse the command line options
-shortop = "s:e:a:b:f:t:G:d:x:M:y:k:T:p:C:O:o:N:i:w:P:u:v:c:F:B:D:X:m:L:g:q:Q:A:U:R:l:hSHZ"
+shortop = "s:e:a:b:f:t:G:d:x:M:y:k:T:p:C:O:o:N:i:w:P:u:v:c:F:B:D:X:m:L:g:q:Q:A:U:R:l:hSHZj:J:Y:"
 longop = [
   "help",
   "gps-start-time=",
@@ -174,9 +178,12 @@ longop = [
   "node-path=",
   "output-jobs-per-node=",
   "min-seg-length=",
-  "use-single=",  
+  "use-single=",
   "use-hot",
   "make-tmp-file",
+  "datafind-path=",
+  "makesfts-path=",
+  "request-memory="
   ]
 
 try:
@@ -194,7 +201,7 @@ dagFileName = None
 auxPath = "."
 tagString = None
 inputDataType = None
-extraDatafindTime = 0L
+extraDatafindTime = 0
 datafindMatch = None
 synchronizeStart = 0
 filterKneeFreq = -1
@@ -221,29 +228,32 @@ nodeListFile = None
 accountingGroup = None
 accountingGroupUser = None
 nodePath = None
-outputJobsPerNode = 0L
+outputJobsPerNode = 0
 useNodeList = False
-nodeListIndex = 0L
+nodeListIndex = 0
 savedOutputSFTPath = None
-minSegLength = 0L
+minSegLength = 0
 useSingle = False
 useHoT = False
 makeTmpFile = False
+datafindPath = None
+makeSFTsPath = None
+requestMemory = None
 
 for o, a in opts:
   if o in ("-h", "--help"):
     usage()
     sys.exit(0)
   elif o in ("-s", "--gps-start-time"):
-    gpsStartTime = long(a)
+    gpsStartTime = int(a)
   elif o in ("-e", "--gps-end-time"):
-    gpsEndTime = long(a)
+    gpsEndTime = int(a)
   elif o in ("-a", "--analysis-start-time"):
-    analysisStartTime = long(a)
+    analysisStartTime = int(a)
   elif o in ("-b", "--analysis-end-time"):
-    analysisEndTime = long(a)    
+    analysisEndTime = int(a)
   elif o in ("-f", "--dag-file"):
-    dagFileName = a   
+    dagFileName = a
   elif o in ("-t", "--aux-path"):
     auxPath = a
   elif o in ("-G", "--tag-string"):
@@ -251,7 +261,7 @@ for o, a in opts:
   elif o in ("-d", "--input-data-type"):
     inputDataType = a
   elif o in ("-x", "--extra-datafind-time"):
-    extraDatafindTime = long(a)
+    extraDatafindTime = int(a)
   elif o in ("-M", "--datafind-match"):
     datafindMatch = a
   elif o in ("-y", "--synchronize-start"):
@@ -259,7 +269,7 @@ for o, a in opts:
   elif o in ("-k", "--filter-knee-freq"):
     filterKneeFreq = int(a)
   elif o in ("-T", "--time-baseline"):
-    timeBaseline = long(a)
+    timeBaseline = int(a)
   elif o in ("-p", "--output-sft-path"):
     outputSFTPath = a
   elif o in ("-C", "--cache-path"):
@@ -283,17 +293,17 @@ for o, a in opts:
   elif o in ("-c", "--comment-field"):
     commentField = a
   elif o in ("-F", "--start-freq"):
-    startFreq = long(a)
+    startFreq = int(a)
   elif o in ("-B", "--band"):
-    freqBand = long(a)
+    freqBand = int(a)
   elif o in ("-D", "--make-gps-dirs"):
     makeGPSDirs = int(a)
   elif o in ("-X", "--misc-desc"):
     miscDesc = a
   elif o in ("-m", "--max-num-per-node"):
-    maxNumPerNode = long(a)
+    maxNumPerNode = int(a)
   elif o in ("-L", "--max-length-all-jobs"):
-    maxLengthAllJobs = long(a)
+    maxLengthAllJobs = int(a)
   elif o in ("-g", "--segment-file"):
     segmentFile = a
   elif o in ("-q", "--list-of-nodes"):
@@ -305,115 +315,133 @@ for o, a in opts:
   elif o in ("-Q", "--node-path"):
     nodePath = a
   elif o in ("-R", "--output-jobs-per-node"):
-    outputJobsPerNode = long(a)
+    outputJobsPerNode = int(a)
   elif o in ("-l", "--min-seg-length"):
-    minSegLength = long(a)
+    minSegLength = int(a)
   elif o in ("-S", "--use-single"):
-    useSingle = True    
+    useSingle = True
   elif o in ("-H", "--use-hot"):
     useHoT = True
   elif o in ("-Z", "--make-tmp-file"):
     makeTmpFile = True
+  elif o in ("-j", "--datafind-path"):
+    datafindPath = a
+  elif o in ("-J", "--makesfts-path"):
+    makeSFTsPath = a
+  elif o in ("-Y", "--request-memory"):
+    requestMemory = a
   else:
-    print >> sys.stderr, "Unknown option:", o
+    print("Unknown option:", o, file=sys.stderr)
     usage()
     sys.exit(1)
 
 if not dagFileName:
-  print >> sys.stderr, "No dag filename specified."
-  print >> sys.stderr, "Use --help for usage details."
+  print("No dag filename specified.", file=sys.stderr)
+  print("Use --help for usage details.", file=sys.stderr)
   sys.exit(1)
 
 if not tagString:
-  print >> sys.stderr, "No tag string specified."
-  print >> sys.stderr, "Use --help for usage details."
+  print("No tag string specified.", file=sys.stderr)
+  print("Use --help for usage details.", file=sys.stderr)
   sys.exit(1)
 
 if not inputDataType:
-  print >> sys.stderr, "No input data type specified."
-  print >> sys.stderr, "Use --help for usage details."
+  print("No input data type specified.", file=sys.stderr)
+  print("Use --help for usage details.", file=sys.stderr)
   sys.exit(1)
 
-if extraDatafindTime < 0L:
-  print >> sys.stderr, "Invalid extra datafind time specified."
-  print >> sys.stderr, "Use --help for usage details."
+if extraDatafindTime < 0:
+  print("Invalid extra datafind time specified.", file=sys.stderr)
+  print("Use --help for usage details.", file=sys.stderr)
   sys.exit(1)
 
 if synchronizeStart<0 or synchronizeStart>1:
-  print >> sys.stderr, "Invalid use of synchronize-start."
-  print >> sys.stderr, "Use --help for usage details."
+  print("Invalid use of synchronize-start.", file=sys.stderr)
+  print("Use --help for usage details.", file=sys.stderr)
   sys.exit(1)
-  
+
 if filterKneeFreq < 0:
-  print >> sys.stderr, "No filter knee frequency specified."
-  print >> sys.stderr, "Use --help for usage details."
+  print("No filter knee frequency specified.", file=sys.stderr)
+  print("Use --help for usage details.", file=sys.stderr)
   sys.exit(1)
 
 if not timeBaseline:
-  print >> sys.stderr, "No time baseline specified."
-  print >> sys.stderr, "Use --help for usage details."
+  print("No time baseline specified.", file=sys.stderr)
+  print("Use --help for usage details.", file=sys.stderr)
   sys.exit(1)
 
 if not outputSFTPath:
-  print >> sys.stderr, "No output SFT path specified."
-  print >> sys.stderr, "Use --help for usage details."
+  print("No output SFT path specified.", file=sys.stderr)
+  print("Use --help for usage details.", file=sys.stderr)
   sys.exit(1)
-  
+
 if not cachePath:
-  print >> sys.stderr, "No cache path specified."
-  print >> sys.stderr, "Use --help for usage details."
+  print("No cache path specified.", file=sys.stderr)
+  print("Use --help for usage details.", file=sys.stderr)
   sys.exit(1)
 
 if not logPath:
-  print >> sys.stderr, "No log path specified."
-  print >> sys.stderr, "Use --help for usage details."
+  print("No log path specified.", file=sys.stderr)
+  print("Use --help for usage details.", file=sys.stderr)
   sys.exit(1)
 
 if not subLogPath:
-  print >> sys.stderr, "No sub log path specified."
-  print >> sys.stderr, "Use --help for usage details."
+  print("No sub log path specified.", file=sys.stderr)
+  print("Use --help for usage details.", file=sys.stderr)
   sys.exit(1)
 
 if not channelName:
-  print >> sys.stderr, "No channel name specified."
-  print >> sys.stderr, "Use --help for usage details."
+  print("No channel name specified.", file=sys.stderr)
+  print("Use --help for usage details.", file=sys.stderr)
   sys.exit(1)
 
 if (windowType != 0) and (windowType != 1) and (windowType != 2) and (windowType != 3):
-  print >> sys.stderr, "Invalid window type specified."
-  print >> sys.stderr, "Use --help for usage details."
+  print("Invalid window type specified.", file=sys.stderr)
+  print("Use --help for usage details.", file=sys.stderr)
   sys.exit(1)
 
 if (overlapFraction < 0.0) or (overlapFraction >= 1.0):
-  print >> sys.stderr, "Invalid make overlap fraction specified."
-  print >> sys.stderr, "Use --help for usage details."
+  print("Invalid make overlap fraction specified.", file=sys.stderr)
+  print("Use --help for usage details.", file=sys.stderr)
   sys.exit(1)
 
 if (sftVersion != 1) and (sftVersion != 2):
-  print >> sys.stderr, "Invalid SFT version specified."
-  print >> sys.stderr, "Use --help for usage details."
+  print("Invalid SFT version specified.", file=sys.stderr)
+  print("Use --help for usage details.", file=sys.stderr)
   sys.exit(1)
 
 if (startFreq < 0.0):
-  print >> sys.stderr, "Invalid start freq specified."
-  print >> sys.stderr, "Use --help for usage details."
+  print("Invalid start freq specified.", file=sys.stderr)
+  print("Use --help for usage details.", file=sys.stderr)
   sys.exit(1)
 
 if (freqBand < 0.0):
-  print >> sys.stderr, "Invalid band specified."
-  print >> sys.stderr, "Use --help for usage details."
+  print("Invalid band specified.", file=sys.stderr)
+  print("Use --help for usage details.", file=sys.stderr)
   sys.exit(1)
 
 if (makeGPSDirs < 0) or (makeGPSDirs > 10):
-  print >> sys.stderr, "Invalid make gps dirs specified."
-  print >> sys.stderr, "Use --help for usage details."
+  print("Invalid make gps dirs specified.", file=sys.stderr)
+  print("Use --help for usage details.", file=sys.stderr)
   sys.exit(1)
 
 if not maxNumPerNode:
-  print >> sys.stderr, "No maximum number of SFTs per node specified."
-  print >> sys.stderr, "Use --help for usage details."
+  print("No maximum number of SFTs per node specified.", file=sys.stderr)
+  print("Use --help for usage details.", file=sys.stderr)
   sys.exit(1)
 
+dataFindExe = 'gw_data_find'
+if datafindPath:
+    dataFindExe = os.path.join(datafindPath,dataFindExe)
+elif 'LSC_DATAFIND_PATH' in os.environ:
+    dataFindExe = os.path.join('$ENV(LSC_DATAFIND_PATH)',dataFindExe)
+
+makeSFTsExe = 'lalapps_MakeSFTs'
+if makeSFTsPath:
+    makeSFTsExe = os.path.join(makeSFTsPath,makeSFTsExe)
+elif 'MAKESFTS_PATH' in os.environ:
+    makeSFTsExe = os.path.join('$ENV(MAKESFTS_PATH)',makeSFTsExe)
+
 # try and make a directory to store the cache files and job logs
 try: os.mkdir(logPath)
 except: pass
@@ -425,11 +453,11 @@ nodeList = [];
 if (nodeListFile != None):
 
     if not nodePath:
-       print >> sys.stderr, "Node file list given, but no node path specified."
+       print("Node file list given, but no node path specified.", file=sys.stderr)
        sys.exit(1)
-    
-    if (outputJobsPerNode < 1L):
-       print >> sys.stderr, "Node file list given, but invalid output jobs per node specified."
+
+    if (outputJobsPerNode < 1):
+       print("Node file list given, but invalid output jobs per node specified.", file=sys.stderr)
        sys.exit(1)
 
     try:
@@ -439,10 +467,10 @@ if (nodeListFile != None):
              nodeList.append(splitLine[0])
          # End for line in open(nodeListFile)
          if (len(nodeList) < 1):
-             print >> sys.stderr, "No nodes found in node list file: %s." % nodeListFile
+             print("No nodes found in node list file: %s." % nodeListFile, file=sys.stderr)
              sys.exit(1)
     except:
-         print >> sys.stderr, "Error reading or parsing node list file: %s." % nodeListFile
+         print("Error reading or parsing node list file: %s." % nodeListFile, file=sys.stderr)
          sys.exit(1)
 
     # Set flag to use list of nodes in constructing output files
@@ -455,21 +483,21 @@ segList = [];
 adjustSegExtraTime = False
 if (segmentFile != None):
 
-    if minSegLength < 0L:
-      print >> sys.stderr, "Invalid minimum segment length specified."
-      print >> sys.stderr, "Use --help for usage details."
+    if minSegLength < 0:
+      print("Invalid minimum segment length specified.", file=sys.stderr)
+      print("Use --help for usage details.", file=sys.stderr)
       sys.exit(1)
 
     # the next flag causes extra time that cannot be processes to be trimmed from the start and end of a segment
     adjustSegExtraTime = True
     try:
          for line in open(segmentFile):
-             try: 
+             try:
                  splitLine = line.split();
-                 try: 
+                 try:
                      oneSeg = [];
-                     oneSeg.append(long(splitLine[0]));
-                     oneSeg.append(long(splitLine[1]));
+                     oneSeg.append(int(splitLine[0]));
+                     oneSeg.append(int(splitLine[1]));
                      if ((oneSeg[1] - oneSeg[0]) >= minSegLength):
                          segList.append(oneSeg)
                      else:
@@ -480,25 +508,25 @@ if (segmentFile != None):
                  pass
          # End for line in open(segmentFile)
          if (len(segList) < 1):
-             print >> sys.stderr, "No segments found in segment file: %s." % segmentFile
+             print("No segments found in segment file: %s." % segmentFile, file=sys.stderr)
              sys.exit(1)
     except:
-         print >> sys.stderr, "Error reading or parsing segment file: %s." % segmentFile
+         print("Error reading or parsing segment file: %s." % segmentFile, file=sys.stderr)
          sys.exit(1)
 else:
     if not analysisStartTime:
-      print >> sys.stderr, "No GPS analysis start time specified."
-      print >> sys.stderr, "Use --help for usage details."
+      print("No GPS analysis start time specified.", file=sys.stderr)
+      print("Use --help for usage details.", file=sys.stderr)
       sys.exit(1)
 
     if not analysisEndTime:
-      print >> sys.stderr, "No GPS analysis end time specified."
-      print >> sys.stderr, "Use --help for usage details."
+      print("No GPS analysis end time specified.", file=sys.stderr)
+      print("Use --help for usage details.", file=sys.stderr)
       sys.exit(1)
 
     if not maxLengthAllJobs:
-      print >> sys.stderr, "No maximum length of all jobs specified."
-      print >> sys.stderr, "Use --help for usage details."
+      print("No maximum length of all jobs specified.", file=sys.stderr)
+      print("Use --help for usage details.", file=sys.stderr)
       sys.exit(1)
 
     # Make sure not to exceed maximum allow analysis
@@ -511,22 +539,22 @@ else:
         oneSeg.append(analysisEndTime);
         segList.append(oneSeg);
     except:
-        print >> sys.stderr, "There was a problem setting up the segment to run on: [%s, %s)." % (analysisStartTime,analysisEndTime)
+        print("There was a problem setting up the segment to run on: [%s, %s)." % (analysisStartTime,analysisEndTime), file=sys.stderr)
         sys.exit(1)
-    
+
 # END if (segmentFile != None)
 
 # Get the IFO site, which is the first letter of the channel name.
 site = channelName[0]
 
 # initialize count of nodes
-nodeCount         = 0L
+nodeCount         = 0
 
 # create datafind.sub
 datafindFID = file('datafind.sub','w')
 datafindLogFile = subLogPath + '/' + 'datafind_' + dagFileName + '.log'
-datafindFID.write('universe = scheduler\n')
-datafindFID.write('executable = $ENV(LSC_DATAFIND_PATH)/gw_data_find\n')
+datafindFID.write('universe = vanilla\n')
+datafindFID.write('executable = ' + dataFindExe + '\n')
 if not datafindMatch:
    dataFindMatchString = ''
 else:
@@ -548,8 +576,9 @@ datafindFID.close
 MakeSFTsFID = file('MakeSFTs.sub','w')
 MakeSFTsLogFile = subLogPath + '/' + 'MakeSFTs_' + dagFileName + '.log'
 MakeSFTsFID.write('universe = vanilla\n')
-MakeSFTsFID.write('executable = $ENV(MAKESFTS_PATH)/lalapps_MakeSFTs\n')
+MakeSFTsFID.write('executable = '+ makeSFTsExe + '\n')
 MakeSFTsFID.write('arguments = $(argList)\n')
+MakeSFTsFID.write('getenv = True\n')
 if (accountingGroup != None):
    MakeSFTsFID.write('accounting_group = %s\n' % accountingGroup)
 if (accountingGroupUser != None):
@@ -558,6 +587,9 @@ MakeSFTsFID.write('log = %s\n' % MakeSFTsLogFile)
 MakeSFTsFID.write('error = %s/MakeSFTs_$(tagstring).err\n' % logPath)
 MakeSFTsFID.write('output = %s/MakeSFTs_$(tagstring).out\n' % logPath)
 MakeSFTsFID.write('notification = never\n')
+if (requestMemory != None):
+    MakeSFTsFID.write('RequestMemory = %s\n' % requestMemory)
+MakeSFTsFID.write('RequestCpus = 1\n')
 MakeSFTsFID.write('queue 1\n')
 MakeSFTsFID.close
 
@@ -569,8 +601,8 @@ startTimeAllNodes = None
 firstSFTstartTime = 0
 for seg in segList:
     # Each segment in the segList runs on one or more nodes; initialize the number SFTs produced by the current node:
-    numThisNode = 0L
-    numThisSeg = 0L
+    numThisNode = 0
+    numThisSeg = 0
     if (adjustSegExtraTime and synchronizeStart==0):
        segStartTime = seg[0]
        segEndTime = seg[1]
@@ -578,12 +610,12 @@ for seg in segList:
        if overlapFraction != 0.0:
           # handle overlap
           if (segEndTime - segStartTime) > timeBaseline:
-             segExtraTime = (segEndTime - segStartTime - timeBaseline) % long((1.0 - overlapFraction)*timeBaseline)
+             segExtraTime = (segEndTime - segStartTime - timeBaseline) % int((1.0 - overlapFraction)*timeBaseline)
           # else there will just one SFT this segment
        else:
           # default case, no overlap
           segExtraTime = (segEndTime - segStartTime) % timeBaseline
-       segExtraStart =  long(segExtraTime / 2)
+       segExtraStart =  int(segExtraTime / 2)
        segExtraEnd = segExtraTime - segExtraStart
        #print segStartTime,segEndTime, segExtraTime, segExtraStart, segExtraEnd
        analysisStartTime = segStartTime + segExtraStart
@@ -594,13 +626,13 @@ for seg in segList:
        segStartTime = seg[0]
        segEndTime = seg[1]
        if firstSFTstartTime == 0: firstSFTstartTime = segStartTime
-       analysisStartTime = long(round(math.ceil((segStartTime - firstSFTstartTime)/((1.0 - overlapFraction)*timeBaseline))*(1.0 - overlapFraction)*timeBaseline)) + firstSFTstartTime
+       analysisStartTime = int(round(math.ceil((segStartTime - firstSFTstartTime)/((1.0 - overlapFraction)*timeBaseline))*(1.0 - overlapFraction)*timeBaseline)) + firstSFTstartTime
        if analysisStartTime > segEndTime: analysisStartTime = segEndTime
-       analysisEndTime = long(round(math.floor((segEndTime - analysisStartTime - timeBaseline)/((1.0 - overlapFraction)*timeBaseline))*(1.0 - overlapFraction)*timeBaseline)) + timeBaseline + analysisStartTime
+       analysisEndTime = int(round(math.floor((segEndTime - analysisStartTime - timeBaseline)/((1.0 - overlapFraction)*timeBaseline))*(1.0 - overlapFraction)*timeBaseline)) + timeBaseline + analysisStartTime
        if analysisEndTime < segStartTime: analysisEndTime = segStartTime
     else:
        analysisStartTime = seg[0]
-       analysisEndTime = seg[1]     
+       analysisEndTime = seg[1]
     #print analysisStartTime, analysisEndTime
     # Loop through the analysis time; make sure no more than maxNumPerNode SFTs are produced by any one node
     startTimeThisNode = analysisStartTime
@@ -610,10 +642,10 @@ for seg in segList:
          # increment endTimeAllNodes by the timeBaseline until we get past the analysisEndTime
          if overlapFraction != 0.0:
             # handle overlap
-            if numThisSeg == 0L:
+            if numThisSeg == 0:
                endTimeAllNodes = endTimeAllNodes + timeBaseline
             else:
-               endTimeAllNodes = endTimeAllNodes + long((1.0 - overlapFraction)*timeBaseline)
+               endTimeAllNodes = endTimeAllNodes + int((1.0 - overlapFraction)*timeBaseline)
          else:
             # default case, no overlap
             endTimeAllNodes = endTimeAllNodes + timeBaseline
@@ -630,31 +662,31 @@ for seg in segList:
 
                if (useNodeList):
                   outputSFTPath = nodePath + nodeList[nodeListIndex] + savedOutputSFTPath
-                  if ((nodeCount % outputJobsPerNode) == 0L):
-                     nodeListIndex = nodeListIndex + 1L
+                  if ((nodeCount % outputJobsPerNode) == 0):
+                     nodeListIndex = nodeListIndex + 1
                   # END if ((nodeCount % outputJobsPerNode) == 0L)
                # END if (useNodeList)
 
                if (nodeCount == 1): startTimeAllNodes = startTimeThisNode
                writeToDag(dagFID,nodeCount, filterKneeFreq, timeBaseline, outputSFTPath, cachePath, startTimeThisNode, endTimeThisNode, channelName, site, inputDataType, extraDatafindTime, useSingle, useHoT, makeTmpFile, tagString, windowType, overlapFraction, sftVersion, makeGPSDirs, miscDesc, commentField, startFreq, freqBand, frameStructType, IFO)
                # Update for next node
-               numThisNode       = 0L
+               numThisNode       = 0
                if overlapFraction != 0.0:
                   # handle overlap
-                  startTimeThisNode = endTimeThisNode - long((overlapFraction)*timeBaseline)
+                  startTimeThisNode = endTimeThisNode - int((overlapFraction)*timeBaseline)
                else:
                   # default case, no overlap
                   startTimeThisNode = endTimeThisNode
     else:
          # we are at or past the analysisEndTime; output job for last node if needed.
-         if (numThisNode > 0L):
+         if (numThisNode > 0):
             # write jobs to dag for this node
             nodeCount = nodeCount + 1
 
             if (useNodeList):
                outputSFTPath = nodePath + nodeList[nodeListIndex] + savedOutputSFTPath
-               if ((nodeCount % outputJobsPerNode) == 0L):
-                  nodeListIndex = nodeListIndex + 1L
+               if ((nodeCount % outputJobsPerNode) == 0):
+                  nodeListIndex = nodeListIndex + 1
                # END if ((nodeCount % outputJobsPerNode) == 0L)
             # END if (useNodeList)
 
@@ -670,13 +702,13 @@ dagFID.close
 endTimeAllNodes = endTimeThisNode
 
 if not startTimeAllNodes:
-  print >> sys.stderr, "The startTimeAllNodes == none; the DAG file contains no jobs!"
+  print("The startTimeAllNodes == none; the DAG file contains no jobs!", file=sys.stderr)
   sys.exit(1)
 
 if (endTimeAllNodes <= startTimeAllNodes):
-  print >> sys.stderr, "The endTimeAllNodes <= startTimeAllNodes; the DAG file contains no jobs!"
+  print("The endTimeAllNodes <= startTimeAllNodes; the DAG file contains no jobs!", file=sys.stderr)
   sys.exit(1)
 
-print >> sys.stdout, startTimeAllNodes, endTimeAllNodes
+print(startTimeAllNodes, endTimeAllNodes)
 
 sys.exit(0)
