@@ -25,6 +25,7 @@
 #include <sys/time.h>
 #include <ctype.h>
 
+#include <lal/ComplexFFT.h>
 #include <lal/LALDatatypes.h>
 #include <lal/LALgetopt.h>
 #include <lal/LIGOMetadataTables.h>
@@ -34,6 +35,7 @@
 #include <lal/LALStdio.h>
 #include <lal/LIGOMetadataTables.h>
 #include <lal/LIGOMetadataUtils.h>
+#include <lal/LIGOMetadataInspiralUtils.h>
 #include <lal/LIGOMetadataRingdownUtils.h>
 #include <lal/AVFactories.h>
 #include <lal/SeqFactories.h>
@@ -41,10 +43,7 @@
 #include <lal/RealFFT.h>
 #include <lal/LALFrStream.h>
 #include <lal/LALInspiral.h>
-#include <lal/FindChirpDatatypes.h>
 #include <lal/FindChirp.h>
-#include <lal/FindChirpSP.h>
-#include <lal/FindChirpTD.h>
 #include <lal/FindChirpPTF.h>
 #include <lal/LIGOLwXML.h>
 #include <lal/LIGOLwXMLInspiralRead.h>
@@ -66,8 +65,9 @@
 #include "spectrm.h"
 #include "segment.h"
 #include "errutil.h"
-#include "processtable.h"
 #include "gpstime.h"
+#include "FindChirpTD.h"
+#include "FindChirpDatatypes.h"
 
 #include <gsl/gsl_matrix.h>
 #include <gsl/gsl_vector.h>
@@ -356,19 +356,27 @@ UINT8 coh_PTF_add_triggers(
     INT8                    slideId,
     REAL4                   *timeOffsets,
     UINT4                   *acceptPointList,
-    UINT4                   numAcceptPoints
+    UINT4                   numAcceptPoints,
+    UINT4                   slideNum,
+    INT4                    timeDiff,
+    INT4                    startTime
 );
 
 void coh_PTF_cluster_triggers(
-  struct coh_PTF_params   *params,
-  MultiInspiralTable      **eventList,
-  MultiInspiralTable      **thisEvent
+    struct coh_PTF_params   *params,
+    MultiInspiralTable      **eventList,
+    MultiInspiralTable      **newEventHead,
+    UINT4                   numSlides,
+    INT4                    timeDiff
 );
 
 UINT4 coh_PTF_accept_trig_check(
     struct coh_PTF_params   *params,
     MultiInspiralTable      **eventList,
-    MultiInspiralTable      thisEvent
+    MultiInspiralTable      thisEvent,
+    INT4                    timeDiff,
+    UINT4                   currTimeDiff,
+    UINT4                   currStorageID
 );
 
 SnglInspiralTable* coh_PTF_create_sngl_event(
@@ -508,7 +516,6 @@ void coh_PTF_create_time_slide_table(
 
 void coh_PTF_initialize_structures(
   struct coh_PTF_params    *params,
-  FindChirpInitParams      **fcInitParamsP,
   FindChirpTemplate        **fcTmpltP,
   FindChirpTmpltParams     **fcTmpltParamsP,
   REAL8Array               **PTFM,
@@ -875,7 +882,6 @@ void coh_PTF_cleanup(
     InspiralTemplate        *PTFbankhead,
     FindChirpTemplate       *fcTmplt,
     FindChirpTmpltParams    *fcTmpltParams,
-    FindChirpInitParams     *fcInitParams,
     REAL8Array              **PTFM,
     REAL8Array              **PTFN,
     COMPLEX8VectorSequence  **PTFqVec,
