@@ -19,6 +19,7 @@
 
 #include "config.h"
 #include "coh_PTF.h"
+#include <lal/LIGOLwXMLlegacy.h>
 
 /*
  *
@@ -76,6 +77,50 @@ ProcessParamsTable * create_process_params( int argc, char **argv,
   return processParamsTable;
 }
 
+static int XLALWriteLIGOLwXMLTimeSlideSegmentMapTable(
+	LIGOLwXMLStream *xml,
+	const TimeSlideSegmentMapTable *time_slide_seg_map
+)
+{
+	const char *row_head = "\n\t\t\t";
+
+	if(xml->table != no_table) {
+		XLALPrintError("a table is still open");
+		XLAL_ERROR(XLAL_EFAILED);
+	}
+
+	/* table header */
+
+	XLALClearErrno();
+	XLALFilePuts("\t<Table Name=\"time_slide_segment_map:table\">\n", xml->fp);
+	XLALFilePuts("\t\t<Column Name=\"time_slide_segment_map:segment_def_id\" Type=\"ilwd:char\"/>\n", xml->fp);
+	XLALFilePuts("\t\t<Column Name=\"time_slide_segment_map:time_slide_id\" Type=\"ilwd:char\"/>\n", xml->fp);
+        XLALFilePuts("\t\t<Stream Name=\"time_slide_segment_map:table\" Type=\"Local\" Delimiter=\",\">", xml->fp);
+	if(XLALGetBaseErrno())
+		XLAL_ERROR(XLAL_EFUNC);
+
+	/* rows */
+
+	for(; time_slide_seg_map; time_slide_seg_map = time_slide_seg_map->next) {
+		if(XLALFilePrintf(xml->fp, "%s\"segment_def:segment_def_id:%ld\",\"time_slide:time_slide_id:%ld\"",
+			row_head,
+			time_slide_seg_map->segment_def_id,
+			time_slide_seg_map->time_slide_id
+		) < 0)
+			XLAL_ERROR(XLAL_EFUNC);
+		row_head = ",\n\t\t\t";
+	}
+
+	/* table footer */
+
+	if(XLALFilePuts("\n\t\t</Stream>\n\t</Table>\n", xml->fp) < 0)
+		XLAL_ERROR(XLAL_EFUNC);
+
+	/* done */
+
+	return 0;
+}
+
 
 /* routine to output events as LIGOLw XML file */
 int coh_PTF_output_events_xml( 
@@ -248,18 +293,18 @@ ProcessTable *coh_PTF_create_process_table( struct coh_PTF_params *params )
   }
   else if( params->numIFO == 2 )
   {   
-    snprintf( processTable->ifos, LIGOMETA_IFOS_MAX,\
+    XLALStringPrint( processTable->ifos, LIGOMETA_IFOS_MAX,\
               "%s%s", params->ifoName[0], params->ifoName[1] );
   }
   else if ( params->numIFO == 3 )
   {
-    snprintf( processTable->ifos, LIGOMETA_IFOS_MAX,\
+    XLALStringPrint( processTable->ifos, LIGOMETA_IFOS_MAX,\
               "%s%s%s", params->ifoName[0], params->ifoName[1],
         params->ifoName[2] );
   }
   else if ( params->numIFO == 4 )
   {
-    snprintf( processTable->ifos, LIGOMETA_IFOS_MAX,\
+    XLALStringPrint( processTable->ifos, LIGOMETA_IFOS_MAX,\
               "%s%s%s%s", params->ifoName[0], params->ifoName[1],
               params->ifoName[2], params->ifoName[3]);
   } 
@@ -282,7 +327,7 @@ SearchSummaryTable *coh_PTF_create_search_summary( struct coh_PTF_params *params
 
   /* setup search summary table */
   searchSummary = LALCalloc( 1, sizeof( *searchSummary ) );
-  strncpy( searchSummary->comment, params->programName, LIGOMETA_COMMENT_MAX );
+  strncpy( searchSummary->comment, params->programName, LIGOMETA_COMMENT_MAX-1 );
   searchSummary->nnodes = 1;
 
   /* compute the start and end times of data analyzed */
@@ -317,18 +362,18 @@ SearchSummaryTable *coh_PTF_create_search_summary( struct coh_PTF_params *params
   }
   else if( params->numIFO == 2 )
   {
-    snprintf( searchSummary->ifos, LIGOMETA_IFOS_MAX,\
+    XLALStringPrint( searchSummary->ifos, LIGOMETA_IFOS_MAX,\
               "%s%s", params->ifoName[0], params->ifoName[1] );
   }
   else if ( params->numIFO == 3 )
   {
-    snprintf( searchSummary->ifos, LIGOMETA_IFOS_MAX,\
+    XLALStringPrint( searchSummary->ifos, LIGOMETA_IFOS_MAX,\
               "%s%s%s", params->ifoName[0], params->ifoName[1],
         params->ifoName[2] );
   }
   else if ( params->numIFO == 4 )
   {
-    snprintf( searchSummary->ifos, LIGOMETA_IFOS_MAX,\
+    XLALStringPrint( searchSummary->ifos, LIGOMETA_IFOS_MAX,\
               "%s%s%s%s", params->ifoName[0], params->ifoName[1],
               params->ifoName[2], params->ifoName[3]);
   }
