@@ -12,14 +12,17 @@ Classes needed for the cosmic string analysis pipeline.
 """
 
 
+from __future__ import print_function
+
+
 import math
 import os
 import sys
 
 
+from ligo import segments
 from glue import iterutils
 from glue import pipeline
-from glue import segments
 from lal import LIGOTimeGPS
 from lal.utils import CacheEntry
 from lalburst import cafe
@@ -75,7 +78,7 @@ class MeasLikelihoodJob(pipeline.CondorDAGJob):
 		self.output_dir = "."
 		self.files_per_meas_likelihood = get_files_per_meas_likelihood(config_parser)
 		if self.files_per_meas_likelihood < 1:
-			raise ValueError, "files_per_meas_likelihood < 1"
+			raise ValueError("files_per_meas_likelihood < 1")
 
 
 class MeasLikelihoodNode(pipeline.CondorDAGNode):
@@ -95,7 +98,7 @@ class MeasLikelihoodNode(pipeline.CondorDAGNode):
 
 	def add_input_cache(self, cache):
 		if self.output_cache:
-			raise AttributeError, "cannot change attributes after computing output cache"
+			raise AttributeError("cannot change attributes after computing output cache")
 		self.input_cache.extend(cache)
 
 	def add_file_arg(self, filename):
@@ -103,7 +106,7 @@ class MeasLikelihoodNode(pipeline.CondorDAGNode):
 
 	def set_output(self, description):
 		if self.output_cache:
-			raise AttributeError, "cannot change attributes after computing output cache"
+			raise AttributeError("cannot change attributes after computing output cache")
 		cache_entry = power.make_cache_entry(self.input_cache, description, "")
 		filename = os.path.join(self.output_dir, "%s-STRING_LIKELIHOOD_%s-%d-%d.xml.gz" % (cache_entry.observatory, cache_entry.description, int(cache_entry.segment[0]), int(abs(cache_entry.segment))))
 		cache_entry.url = "file://localhost" + os.path.abspath(filename)
@@ -117,13 +120,13 @@ class MeasLikelihoodNode(pipeline.CondorDAGNode):
 
 	def get_output_cache(self):
 		if not self.output_cache:
-			raise AttributeError, "must call set_output(description) first"
+			raise AttributeError("must call set_output(description) first")
 		return self.output_cache
 
 	def write_input_files(self, *args):
 		f = file(self.cache_name, "w")
 		for c in self.input_cache:
-			print >>f, str(c)
+			print(str(c), file=f)
 		pipeline.CondorDAGNode.write_input_files(self, *args)
 
 	def get_output_files(self):
@@ -145,7 +148,7 @@ class CalcLikelihoodJob(pipeline.CondorDAGJob):
 		self.cache_dir = power.get_cache_dir(config_parser)
 		self.files_per_calc_likelihood = get_files_per_calc_likelihood(config_parser)
 		if self.files_per_calc_likelihood < 1:
-			raise ValueError, "files_per_calc_likelihood < 1"
+			raise ValueError("files_per_calc_likelihood < 1")
 
 
 class CalcLikelihoodNode(pipeline.CondorDAGNode):
@@ -187,10 +190,10 @@ class CalcLikelihoodNode(pipeline.CondorDAGNode):
 	def write_input_files(self, *args):
 		f = file(self.cache_name, "w")
 		for c in self.input_cache:
-			print >>f, str(c)
+			print(str(c), file=f)
 		f = file(self.likelihood_cache_name, "w")
 		for c in self.likelihood_cache:
-			print >>f, str(c)
+			print(str(c), file=f)
 		pipeline.CondorDAGNode.write_input_files(self, *args)
 
 	def get_output_files(self):
@@ -246,14 +249,14 @@ class StringNode(pipeline.CondorDAGNode,pipeline.AnalysisNode):
     the config file.
     """
     if self.output_cache:
-      raise AttributeError, "cannot change attributes after computing output cache"
+      raise AttributeError("cannot change attributes after computing output cache")
     pipeline.AnalysisNode.set_ifo(self, instrument)
     for optvalue in self.job()._AnalysisJob__cp.items("lalapps_StringSearch_%s" % instrument):
       self.add_var_arg("--%s %s" % optvalue)
 
   def set_user_tag(self, tag):
     if self.output_cache:
-      raise AttributeError, "cannot change attributes after computing output cache"
+      raise AttributeError("cannot change attributes after computing output cache")
     self.__usertag = tag
     self.add_var_opt("user-tag", self.__usertag)
 
@@ -280,7 +283,7 @@ class StringNode(pipeline.CondorDAGNode,pipeline.AnalysisNode):
     """
     if self._AnalysisNode__output is None:
       if None in (self.get_start(), self.get_end(), self.get_ifo(), self.__usertag):
-        raise ValueError, "start time, end time, ifo, or user tag has not been set"
+        raise ValueError("start time, end time, ifo, or user tag has not been set")
       seg = segments.segment(LIGOTimeGPS(self.get_start()), LIGOTimeGPS(self.get_end()))
       self.set_output(os.path.join(self.output_dir, "%s-STRINGSEARCH_%s-%d-%d.xml.gz" % (self.get_ifo(), self.__usertag, int(self.get_start()), int(self.get_end()) - int(self.get_start()))))
 
@@ -297,31 +300,31 @@ class StringNode(pipeline.CondorDAGNode,pipeline.AnalysisNode):
 
 class RunSqliteJob(pipeline.CondorDAGJob):
 	"""
-        A lalapps_run_sqlite job used by the gstlal pipeline. The static
-        options are read from the [lalapps_run_sqlite] section in the ini
-        file.  The stdout and stderr from the job are directed to the logs
-        directory.  The job runs in the universe specified in the ini file.
-        The path to the executable is determined from the ini file.
+	A lalapps_run_sqlite job used by the gstlal pipeline. The static
+	options are read from the [lalapps_run_sqlite] section in the ini
+	file.  The stdout and stderr from the job are directed to the logs
+	directory.  The job runs in the universe specified in the ini file.
+	The path to the executable is determined from the ini file.
 	"""
-        def __init__(self, config_parser):
-                """
-                config_parser = ConfigParser object
-                """
-                pipeline.CondorDAGJob.__init__(self, "vanilla", power.get_executable(config_parser, "lalapps_run_sqlite"))
-                self.add_ini_opts(config_parser, "lalapps_run_sqlite")
-                self.set_stdout_file(os.path.join(power.get_out_dir(config_parser), "lalapps_run_sqlite-$(cluster)-$(process).out"))
-                self.set_stderr_file(os.path.join(power.get_out_dir(config_parser), "lalapps_run_sqlite-$(cluster)-$(process).err"))
+	def __init__(self, config_parser):
+		"""
+		config_parser = ConfigParser object
+		"""
+		pipeline.CondorDAGJob.__init__(self, "vanilla", power.get_executable(config_parser, "lalapps_run_sqlite"))
+		self.add_ini_opts(config_parser, "lalapps_run_sqlite")
+		self.set_stdout_file(os.path.join(power.get_out_dir(config_parser), "lalapps_run_sqlite-$(cluster)-$(process).out"))
+		self.set_stderr_file(os.path.join(power.get_out_dir(config_parser), "lalapps_run_sqlite-$(cluster)-$(process).err"))
 		self.add_condor_cmd("getenv", "True")
 		self.add_condor_cmd("accounting_group", power.get_accounting_group(config_parser))
-                self.set_sub_file("lalapps_run_sqlite.sub")
+		self.set_sub_file("lalapps_run_sqlite.sub")
 		self.files_per_run_sqlite = get_files_per_run_sqlite(config_parser)
 		if self.files_per_run_sqlite < 1:
-			raise ValueError, "files_per_run_sqlite < 1"
+			raise ValueError("files_per_run_sqlite < 1")
 
 
 class RunSqliteNode(pipeline.CondorDAGNode):
-        def __init__(self, *args):
-                pipeline.CondorDAGNode.__init__(self, *args)
+	def __init__(self, *args):
+		pipeline.CondorDAGNode.__init__(self, *args)
 		self.input_cache = []
 		self.output_cache = self.input_cache
 		self._CondorDAGNode__macros["initialdir"] = os.getcwd()
@@ -513,7 +516,7 @@ def make_string_fragment(dag, parents, instrument, seg, tag, framecache, injargs
 def split_segment(seg, min_segment_length, pad, overlap, short_segment_duration, max_job_length):
 	# avoid infinite loop
 	if min_segment_length + 2 * pad <= overlap:
-		raise ValueError, "infinite loop: min_segment_length + 2 * pad must be > overlap"
+		raise ValueError("infinite loop: min_segment_length + 2 * pad must be > overlap")
 
 	# clip max_job_length down to an allowed size
 	max_job_length = clip_segment_length(max_job_length, pad, short_segment_duration)
@@ -528,11 +531,11 @@ def split_segment(seg, min_segment_length, pad, overlap, short_segment_duration,
 		assert abs(seglist[-1]) != 0	# safety-check for no-op
 		# bounds must be integers
 		if abs((int(seglist[-1][0]) - seglist[-1][0]) / seglist[-1][0]) > 1e-14 or abs((int(seglist[-1][1]) - seglist[-1][1]) / seglist[-1][1]) > 1e-14:
-			raise ValueError, "segment %s does not have integer boundaries" % str(seglist[-1])
+			raise ValueError("segment %s does not have integer boundaries" % str(seglist[-1]))
 		# advance segment
 		seg = segments.segment(seglist[-1][1] - overlap, seg[1])
 	if not seglist:
-		raise ValueError, "unable to use segment %s" % str(seg)
+		raise ValueError("unable to use segment %s" % str(seg))
 	return seglist
 
 
@@ -555,7 +558,7 @@ def make_string_segment_fragment(dag, datafindnodes, instrument, seg, tag, min_s
 		injargs = {}
 	seglist = split_segment(seg, min_segment_length, pad, overlap, short_segment_duration, max_job_length)
 	if verbose:
-		print >>sys.stderr, "Segment split: " + str(seglist)
+		print("Segment split: " + str(seglist), file=sys.stderr)
 	nodes = set()
 	for seg in seglist:
 		nodes |= make_string_fragment(dag, datafindnodes | binjnodes, instrument, seg, tag, framecache, injargs = injargs)
@@ -572,12 +575,12 @@ def make_single_instrument_stage(dag, datafinds, seglistdict, tag, min_segment_l
 	for instrument, seglist in seglistdict.items():
 		for seg in seglist:
 			if verbose:
-				print >>sys.stderr, "generating %s fragment %s" % (instrument, str(seg))
+				print("generating %s fragment %s" % (instrument, str(seg)), file=sys.stderr)
 
 			# find the datafind job this job is going to need
 			dfnodes = set([node for node in datafinds if (node.get_ifo() == instrument) and (seg in segments.segment(node.get_start(), node.get_end()))])
 			if len(dfnodes) != 1:
-				raise ValueError, "error, not exactly 1 datafind is suitable for trigger generator job at %s in %s" % (str(seg), instrument)
+				raise ValueError("error, not exactly 1 datafind is suitable for trigger generator job at %s in %s" % (str(seg), instrument))
 
 			# trigger generator jobs
 			nodes |= make_string_segment_fragment(dag, dfnodes, instrument, seg, tag, min_segment_length, pad, overlap, short_segment_duration, max_job_length, binjnodes = binjnodes, verbose = verbose)
@@ -605,7 +608,7 @@ WHERE
 
 VACUUM;"""
 
-	print >>file(filename, "w"), code
+	print(code, file=file(filename, "w"))
 
 	return filename
 
