@@ -17,26 +17,30 @@ the standalone ring code on LIGO data
 """
 
 
-import ConfigParser
+from __future__ import print_function
+
+
 import itertools
 from optparse import OptionParser
 import os
 import sys
 import tempfile
+try:
+	from configparser import ConfigParser
+except ImportError:  # python < 3
+	from ConfigParser import ConfigParser
 
 
 from glue import pipeline
-from glue import segments
-from glue import segmentsUtils
-from glue.ligolw import lsctables
-from glue.ligolw import utils as ligolw_utils
-from glue.ligolw.utils import segments as ligolw_segments
-from glue import offsetvector
+from ligo.lw import lsctables
+from ligo.lw import utils as ligolw_utils
+from ligo.lw.utils import segments as ligolw_segments
 from lal import LIGOTimeGPS
 from lal.utils import CacheEntry
-from lalburst import timeslides
+from lalburst import offsetvector
 from lalapps import cosmicstring
 from lalapps import power
+from ligo import segments
 
 __author__ = 'Xavier Siemens<siemens@gravity.phys.uwm.edu>'
 __date__ = '$Date$'
@@ -59,7 +63,7 @@ def parse_command_line():
 	)
 	parser.add_option("-f", "--config-file", metavar = "filename", help = "Use this configuration file (required).")
 	parser.add_option("-l", "--log-path", metavar = "path", help = "Make condor put log files in this directory (required).")
-	parser.add_option("--background-time-slides", metavar = "filename", action = "append", help = "Set the name of the file from which to obtain the time slide table for use in the background branch of the pipeline (required).  This option can be given multiple times to parallelize the background analysis across time slides.  You will want to make sure the time slide files have distinct vectors to not repeat the same analysis multiple times, and in particular you'll want to make sure only one of them has a zero-lag vector in it.") 
+	parser.add_option("--background-time-slides", metavar = "filename", action = "append", help = "Set the name of the file from which to obtain the time slide table for use in the background branch of the pipeline (required).  This option can be given multiple times to parallelize the background analysis across time slides.  You will want to make sure the time slide files have distinct vectors to not repeat the same analysis multiple times, and in particular you'll want to make sure only one of them has a zero-lag vector in it.")
 	parser.add_option("--injection-time-slides", metavar = "filename", help = "Set the name of the file from which to obtain the time slide table for use in the injection branch of the pipeline (required).")
 	parser.add_option("--segments-file", metavar = "filename", help = "Set the name of the LIGO Light-Weight XML file from which to obtain segment lists (required).  See ligolw_segments and ligolw_segment_query for more information on constructing an XML-format segments file.  See also --segments-name.")
 	parser.add_option("--segments-name", metavar = "name", default = "segments", help = "Set the name of the segment lists to retrieve from the segments file (default = \"segments\").  See also --segments-file.")
@@ -72,7 +76,7 @@ def parse_command_line():
 	required_options = ["log_path", "config_file", "background_time_slides", "injection_time_slides", "segments_file"]
 	missing_options = [option for option in required_options if getattr(options, option) is None]
 	if missing_options:
-		raise ValueError, "missing required options %s" % ", ".join(sorted("--%s" % option.replace("_", "-") for option in missing_options))
+		raise ValueError("missing required options %s" % ", ".join(sorted("--%s" % option.replace("_", "-") for option in missing_options)))
 
 	if options.vetoes_file is not None:
 		options.vetoes_cache = set([CacheEntry(None, "VETO", None, "file://localhost" + os.path.abspath(options.vetoes_file))])
@@ -103,16 +107,16 @@ basename = os.path.splitext(os.path.basename(options.config_file))[0]
 log_fh = open(basename + '.pipeline.log', 'w')
 # FIXME: the following code uses obsolete CVS ID tags.
 # It should be modified to use git version information.
-print >>log_fh, "$Id$\nInvoked with arguments:"
+print("$Id$\nInvoked with arguments:", file=log_fh)
 for name_value in options.__dict__.items():
-	print >>log_fh, "%s %s" % name_value
-print >>log_fh
+	print("%s %s" % name_value, file=log_fh)
+print(file=log_fh)
 
 #
 # create the config parser object and read in the ini file
 #
 
-config_parser = ConfigParser.ConfigParser()
+config_parser = ConfigParser()
 config_parser.read(options.config_file)
 
 #
@@ -179,11 +183,11 @@ seglists = ligolw_segments.segmenttable_get_by_name(ligolw_utils.load_filename(o
 # remove extra instruments
 for instrument in set(seglists) - instruments:
 	if options.verbose:
-		print >>sys.stderr, "warning: ignoring segments for '%s' found in '%s'" % (instrument, options.segments_file)
+		print("warning: ignoring segments for '%s' found in '%s'" % (instrument, options.segments_file), file=sys.stderr)
 	del seglists[instrument]
 # check for missing instruments
 if not instruments.issubset(set(seglists)):
-	raise ValueError, "segment lists retrieved from '%s' missing segments for instruments %s" % (options.segments_file, ", ".join(instruments - set(seglists)))
+	raise ValueError("segment lists retrieved from '%s' missing segments for instruments %s" % (options.segments_file, ", ".join(instruments - set(seglists))))
 # now rely on seglists' keys to provide the instruments
 del instruments
 
@@ -193,7 +197,7 @@ del instruments
 #
 
 if options.verbose:
-	print >>sys.stderr, "Computing segments for which lalapps_StringSearch jobs are required ..."
+	print("Computing segments for which lalapps_StringSearch jobs are required ...", file=sys.stderr)
 
 background_time_slides = {}
 background_seglists = segments.segmentlistdict()
@@ -212,7 +216,7 @@ injection_seglists = segments.segmentlistdict()
 for filename in options.injection_time_slides:
 	cache_entry = CacheEntry(None, "INJ", None, "file://localhost" + os.path.abspath(filename))
 
-        injection_time_slides[cache_entry] = lsctables.TimeSlideTable.get_table(ligolw_utils.load_filename(filename, verbose = options.verbose, contenthandler = ligolw_segments.LIGOLWContentHandler)).as_dict().values()
+	injection_time_slides[cache_entry] = lsctables.TimeSlideTable.get_table(ligolw_utils.load_filename(filename, verbose = options.verbose, contenthandler = ligolw_segments.LIGOLWContentHandler)).as_dict().values()
 
 	for i in range(len(injection_time_slides[cache_entry])):
 		injection_time_slides[cache_entry][i] = offsetvector.offsetvector((instrument, LIGOTimeGPS(offset)) for instrument, offset in injection_time_slides[cache_entry][i].items())
@@ -230,7 +234,7 @@ def check_for_reused_offsetvectors(background_time_slides, injection_time_slides
 	for background_cache_entry, background_offsetvector in [(cache_entry, offsetvector) for cache_entry, offsetvectors in background_time_slides.items() for offsetvector in offsetvectors]:
 		for injection_cache_entry, injection_offsetvector in [(cache_entry, offsetvector) for cache_entry, offsetvectors in injection_time_slides.items() for offsetvector in offsetvectors]:
 			if background_offsetvector.deltas == injection_offsetvector.deltas:
-				raise ValueError, "injections offset vector %s from %s is the same as non-injections offset vector %s from %s.  to avoid a self-selection bias, injections must not be performed at the same relative time shifts as a non-injection run" % (str(injection_offsetvector), injection_cache_entry.url, str(background_offsetvector), background_cache_entry.url)
+				raise ValueError("injections offset vector %s from %s is the same as non-injections offset vector %s from %s.  to avoid a self-selection bias, injections must not be performed at the same relative time shifts as a non-injection run" % (str(injection_offsetvector), injection_cache_entry.url, str(background_offsetvector), background_cache_entry.url))
 
 check_for_reused_offsetvectors(background_time_slides, injection_time_slides)
 
@@ -317,7 +321,7 @@ def make_coinc_branch(dag, datafinds, seglists, time_slides, min_segment_length,
 	coinc_nodes = []
 	for n, (time_slides_cache_entry, these_time_slides) in enumerate(time_slides.items()):
 		if verbose:
-			print >>sys.stderr, "%s %d/%d (%s):" % (tag, n + 1, len(time_slides), time_slides_cache_entry.path)
+			print("%s %d/%d (%s):" % (tag, n + 1, len(time_slides), time_slides_cache_entry.path), file=sys.stderr)
 		coinc_nodes.append(set())
 
 		#
@@ -369,10 +373,10 @@ def make_coinc_branch(dag, datafinds, seglists, time_slides, min_segment_length,
 		#
 
 		if verbose:
-			print >>sys.stderr, "building burca jobs ..."
+			print("building burca jobs ...", file=sys.stderr)
 		coinc_nodes[-1] |= power.make_burca_fragment(dag, lladd_nodes, "%s_%d" % (tag, n), verbose = verbose)
 		if verbose:
-			print >>sys.stderr, "done %s %d/%d" % (tag, n + 1, len(time_slides))
+			print("done %s %d/%d" % (tag, n + 1, len(time_slides)), file=sys.stderr)
 
 	#
 	# lalapps_binjfind
@@ -380,7 +384,7 @@ def make_coinc_branch(dag, datafinds, seglists, time_slides, min_segment_length,
 
 	if do_injections:
 		if verbose:
-			print >>sys.stderr, "building binjfind jobs ..."
+			print("building binjfind jobs ...", file=sys.stderr)
 		coinc_nodes = [power.make_binjfind_fragment(dag, these_coinc_nodes, "%s_%d" % (tag, n), verbose = verbose) for n, these_coinc_nodes in enumerate(coinc_nodes)]
 
 	#
@@ -388,7 +392,7 @@ def make_coinc_branch(dag, datafinds, seglists, time_slides, min_segment_length,
 	#
 
 	if verbose:
-		print >>sys.stderr, "building sqlite jobs ..."
+		print("building sqlite jobs ...", file=sys.stderr)
 	coinc_nodes = [power.make_sqlite_fragment(dag, these_coinc_nodes, "%s_%d" % (tag, n), verbose = verbose) for n, these_coinc_nodes in enumerate(coinc_nodes)]
 	coinc_nodes = [cosmicstring.make_run_sqlite_fragment(dag, these_coinc_nodes, "%s_%d" % (tag, n), clipsegments_sql_filename) for n, these_coinc_nodes in enumerate(coinc_nodes)]
 
@@ -397,7 +401,7 @@ def make_coinc_branch(dag, datafinds, seglists, time_slides, min_segment_length,
 	#
 
 	if verbose:
-		print >>sys.stderr, "building lalapps_string_meas_likelihood jobs ..."
+		print("building lalapps_string_meas_likelihood jobs ...", file=sys.stderr)
 	likelihood_nodes = [cosmicstring.make_meas_likelihood_fragment(dag, these_coinc_nodes, "%s_%d" % (tag, n)) for n, these_coinc_nodes in enumerate(coinc_nodes)]
 
 	#
@@ -405,7 +409,7 @@ def make_coinc_branch(dag, datafinds, seglists, time_slides, min_segment_length,
 	#
 
 	if verbose:
-		print >>sys.stderr, "writing output cache ..."
+		print("writing output cache ...", file=sys.stderr)
 	for n, (these_coinc_nodes, these_likelihood_nodes) in enumerate(zip(coinc_nodes, likelihood_nodes)):
 		power.write_output_cache(these_coinc_nodes | these_likelihood_nodes, "%s_%s_output.cache" % (os.path.splitext(dag.get_dag_file())[0], "%s_%d" % (tag, n)))
 
@@ -455,7 +459,7 @@ all_injection_likelihood_nodes = flatten_node_groups(injection_likelihood_nodes)
 
 
 if options.verbose:
-	print >>sys.stderr, "building lalapps_string_calc_likelihood jobs ..."
+	print("building lalapps_string_calc_likelihood jobs ...", file=sys.stderr)
 
 def round_robin_and_flatten(injection_coinc_node_groups, injection_likelihood_node_groups):
 	# round-robin the node lists
@@ -499,7 +503,7 @@ coinc_nodes |= cosmicstring.make_calc_likelihood_fragment(dag, flatten_node_grou
 #
 
 if options.verbose:
-	print >>sys.stderr, "writing dag ..."
+	print("writing dag ...", file=sys.stderr)
 dag.write_sub_files()
 dag.write_dag()
 cosmicstring.write_clip_segment_sql_file(clipsegments_sql_filename)
@@ -508,7 +512,7 @@ cosmicstring.write_clip_segment_sql_file(clipsegments_sql_filename)
 # write a message telling the user that the DAG has been written
 #
 
-print """Created a DAG file which can be submitted by executing
+print("""Created a DAG file which can be submitted by executing
 
 $ condor_submit_dag %s
 
@@ -520,4 +524,4 @@ submit machine by running the commands
 $ unset X509_USER_PROXY
 $ grid-proxy-init -hours $((24*7)):00
 
-""" % dag.get_dag_file()
+""" % dag.get_dag_file())
